@@ -50,6 +50,7 @@
 #include <limits.h>                    // PATH_MAX
 #include <ctype.h>
 #include <pthread.h>
+#include <signal.h>
 
 #ifdef HAVE_LIBXFIXES
 #include <X11/X.h>
@@ -80,7 +81,7 @@
 static XVC_ErrorListItem *errorlist_append (int code, XVC_ErrorListItem * err,
                                             XVC_AppData * app);
 static void error_write_action_msg (int code);
-static void appdata_set_display ();
+static void appdata_set_display (XVC_AppData * app);
 #endif     // DOXYGEN_SHOULD_SKIP_THIS
 
 /**
@@ -111,11 +112,19 @@ appdata_new ()
  * \brief frees the global XVC_AppData struct
  */
 void
-xvc_appdata_free ()
+xvc_appdata_free (XVC_AppData * lapp)
 {
 #define DEBUGFUNCTION "xvc_appdata_free()"
-    if (app) {
+    if (app != NULL) {
+        pthread_mutex_destroy (&(lapp->recording_paused_mutex));
+        pthread_cond_destroy (&(lapp->recording_condition_unpaused));
+        pthread_mutex_destroy (&(lapp->capturing_mutex));
+#ifdef USE_XDAMAGE
+        pthread_mutex_destroy (&(lapp->damage_regions_mutex));
+#endif     // USE_XDAMAGE
+
         free (app);
+        app = NULL;
     }
 #undef DEBUGFUNCTION
 }
@@ -130,7 +139,7 @@ XVC_AppData *
 xvc_appdata_ptr (void)
 {
 #define DEBUGFUNCTION "xvc_appdata_ptr()"
-    if (!app) {
+    if (app == NULL) {
         appdata_new ();
         xvc_appdata_init (app);
     }
@@ -199,6 +208,18 @@ xvc_appdata_init (XVC_AppData * lapp)
     lapp->dmg_event_base = 0;
 #endif     // USE_XDAMAGE
 
+    pthread_mutex_init (&(lapp->recording_paused_mutex), NULL);
+    pthread_cond_init (&(lapp->recording_condition_unpaused), NULL);
+    pthread_mutex_init (&(lapp->capturing_mutex), NULL);
+    lapp->recording_thread_running = FALSE;
+#ifdef USE_XDAMAGE
+    pthread_mutex_init (&(lapp->damage_regions_mutex), NULL);
+#endif     // USE_XDAMAGE
+
+#ifdef USE_DBUS
+    lapp->xso = NULL;
+#endif     // USE_DBUS
+
     xvc_captypeoptions_init (&(lapp->single_frame));
 #ifdef USE_FFMPEG
     xvc_captypeoptions_init (&(lapp->multi_frame));
@@ -217,7 +238,7 @@ xvc_appdata_set_defaults (XVC_AppData * lapp)
 #define DEBUGFUNCTION "xvc_appdata_set_defaults"
     // initialize general options
     // we need the display first
-    lapp->dpy = xvc_frame_get_capture_display ();
+    appdata_set_display (lapp);
 
     // flags related settings
     lapp->flags = FLG_ALWAYS_SHOW_RESULTS;
@@ -225,30 +246,30 @@ xvc_appdata_set_defaults (XVC_AppData * lapp)
 #ifdef HAVE_LIBXFIXES
     {
         int a, b;
-        Display *dpy = xvc_frame_get_capture_display ();
 
-        if (XFixesQueryExtension (dpy, &a, &b))
+        if (XFixesQueryExtension (lapp->dpy, &a, &b))
             lapp->flags |= FLG_USE_XFIXES;
 
 #ifdef USE_XDAMAGE
         a = 2;
         b = 0;
         if (lapp->use_xdamage != 0 &&
-            XFixesQueryVersion (dpy, &a, &b) && a >= 2) {
-            if (XDamageQueryExtension (dpy, &(lapp->dmg_event_base), &b)) {
+            XFixesQueryVersion (lapp->dpy, &a, &b) && a >= 2) {
+            if (XDamageQueryExtension (lapp->dpy, &(lapp->dmg_event_base), &b)) {
                 Window *wm_child = NULL;
                 Atom nwm_atom, utf8_string, wm_name_atom, rt;
                 unsigned long nbytes, nitems;
                 char *wm_name_str = NULL;
                 int fmt;
 
-                utf8_string = XInternAtom (dpy, "UTF8_STRING", False);
+                utf8_string = XInternAtom (lapp->dpy, "UTF8_STRING", False);
 
-                nwm_atom = XInternAtom (dpy, "_NET_SUPPORTING_WM_CHECK", True);
-                wm_name_atom = XInternAtom (dpy, "_NET_WM_NAME", True);
+                nwm_atom =
+                    XInternAtom (lapp->dpy, "_NET_SUPPORTING_WM_CHECK", True);
+                wm_name_atom = XInternAtom (lapp->dpy, "_NET_WM_NAME", True);
 
                 if (nwm_atom != None && wm_name_atom != None) {
-                    if (XGetWindowProperty (dpy, DefaultRootWindow (dpy),
+                    if (XGetWindowProperty (lapp->dpy, lapp->root_window,
                                             nwm_atom, 0, 100,
                                             False, XA_WINDOW,
                                             &rt, &fmt, &nitems, &nbytes,
@@ -260,11 +281,11 @@ xvc_appdata_set_defaults (XVC_AppData * lapp)
                                  DEBUGFILE, DEBUGFUNCTION);
                     }
                     if ((wm_child == NULL) ||
-                        (XGetWindowProperty (dpy, *wm_child, wm_name_atom, 0,
-                                             100, False, utf8_string, &rt, &fmt,
-                                             &nitems, &nbytes,
-                                             (unsigned char **) ((void *)
-                                                                 &wm_name_str))
+                        (XGetWindowProperty
+                         (lapp->dpy, *wm_child, wm_name_atom, 0, 100, False,
+                          utf8_string, &rt, &fmt, &nitems, &nbytes,
+                          (unsigned char **) ((void *)
+                                              &wm_name_str))
                          != Success)) {
                         fprintf (stderr,
                                  "%s %s: Warning!!!\nYour window manager appears to be non-compliant!\n",
@@ -278,7 +299,8 @@ xvc_appdata_set_defaults (XVC_AppData * lapp)
                                                !strcmp (wm_name_str, "compiz")
                                                || !strncmp (wm_name_str,
                                                             "beryl", 5))) {
-                    lapp->dmg_event_base = 0;
+                    lapp->flags &= ~(FLG_USE_XDAMAGE);
+//                    lapp->dmg_event_base = 0;
                 } else {
                     lapp->flags |= FLG_USE_XDAMAGE;
                 }
@@ -292,14 +314,13 @@ xvc_appdata_set_defaults (XVC_AppData * lapp)
 #ifdef HasDGA
     {
         int dgy_evb, dga_errb;
-        Display *dpy = xvc_frame_get_capture_display ();
 
-        if (!XF86DGAQueryExtension (dpy, &dga_evb, &dga_errb))
+        if (!XF86DGAQueryExtension (lapp->dpy, &dga_evb, &dga_errb))
             app->flags &= ~FLG_USE_DGA;
         else {
             int flag = 0;
 
-            XF86DGAQueryDirectVideo (dpy, XDefaultScreen (dpy), &flag);
+            XF86DGAQueryDirectVideo (lapp->dpy, lapp->default_screen, &flag);
             if ((flag & XF86DGADirectPresent) == 0) {
                 app->flags &= ~FLG_USE_DGA;
                 if (app->verbose) {
@@ -311,7 +332,7 @@ xvc_appdata_set_defaults (XVC_AppData * lapp)
     }
 #endif     // HasDGA
 #ifdef HAVE_SHMAT
-    if (!XShmQueryExtension (xvc_frame_get_capture_display ()))
+    if (!XShmQueryExtension (lapp->dpy))
         app->flags &= ~FLG_USE_SHM;
 #endif     // HAVE_SHMAT
 
@@ -336,7 +357,7 @@ xvc_appdata_set_defaults (XVC_AppData * lapp)
     lapp->area->width = 192;
     lapp->area->height = 144;
     lapp->area->x = lapp->area->y = -1;
-    xvc_get_window_attributes (None, &(lapp->win_attr));
+    xvc_get_window_attributes (lapp->dpy, lapp->root_window, &(lapp->win_attr));
 
     // default mode of capture
 #ifdef USE_FFMPEG
@@ -345,6 +366,10 @@ xvc_appdata_set_defaults (XVC_AppData * lapp)
     lapp->default_mode = 0;
 #endif     // USE_FFMPEG
 
+#ifdef USE_DBUS
+    lapp->xso = xvc_server_object_new ();
+#endif     // USE_DBUS
+
     // initialzie options specific to either single- or multi-frame capture
     lapp->single_frame.quality = lapp->multi_frame.quality = 90;
     lapp->single_frame.step = lapp->multi_frame.step = 1;
@@ -399,7 +424,8 @@ xvc_appdata_set_defaults (XVC_AppData * lapp)
  * @see XVC_CapTypeOptions
  */
 void
-xvc_captypeoptions_copy (XVC_CapTypeOptions * topts, XVC_CapTypeOptions * sopts)
+xvc_captypeoptions_copy (XVC_CapTypeOptions * topts,
+                         const XVC_CapTypeOptions * sopts)
 {
     topts->file = strdup (sopts->file);
     topts->target = sopts->target;
@@ -432,7 +458,7 @@ xvc_captypeoptions_copy (XVC_CapTypeOptions * topts, XVC_CapTypeOptions * sopts)
  * @see XVC_AppData
  */
 void
-xvc_appdata_copy (XVC_AppData * tapp, XVC_AppData * sapp)
+xvc_appdata_copy (XVC_AppData * tapp, const XVC_AppData * sapp)
 {
     tapp->use_xdamage = sapp->use_xdamage;
     tapp->verbose = sapp->verbose;
@@ -440,6 +466,12 @@ xvc_appdata_copy (XVC_AppData * tapp, XVC_AppData * sapp)
     tapp->rescale = sapp->rescale;
     tapp->mouseWanted = sapp->mouseWanted;
     tapp->dpy = sapp->dpy;
+    tapp->root_window = sapp->root_window;
+    tapp->default_screen = sapp->default_screen;
+    tapp->default_screen_num = sapp->default_screen_num;
+    tapp->max_width = sapp->max_width;
+    tapp->max_height = sapp->max_height;
+
     tapp->win_attr = sapp->win_attr;
     tapp->area = sapp->area;
 #ifdef USE_XDAMAGE
@@ -454,6 +486,18 @@ xvc_appdata_copy (XVC_AppData * tapp, XVC_AppData * sapp)
     tapp->device = strdup (sapp->device);
 #endif     // HasVideo4Linux
 
+#ifdef USE_DBUS
+    tapp->xso = sapp->xso;
+#endif     // USE_DBUS
+
+    tapp->recording_paused_mutex = sapp->recording_paused_mutex;
+    tapp->recording_condition_unpaused = sapp->recording_condition_unpaused;
+    tapp->capturing_mutex = sapp->capturing_mutex;
+    tapp->recording_thread_running = sapp->recording_thread_running;
+#ifdef USE_XDAMAGE
+    tapp->damage_regions_mutex = sapp->damage_regions_mutex;
+#endif     // USE_XDAMAGE
+
     tapp->default_mode = sapp->default_mode;
     tapp->current_mode = sapp->current_mode;
     xvc_captypeoptions_copy (&(tapp->single_frame), &(sapp->single_frame));
@@ -482,8 +526,6 @@ xvc_appdata_validate (XVC_AppData * lapp, int mode, int *rc)
     XVC_CapTypeOptions *target = NULL;
     XVC_ErrorListItem *errors = NULL;
     int t_codec, t_format;
-    Display *dpy;
-    int max_width, max_height;
 
 #ifdef USE_FFMPEG
     XVC_CapTypeOptions *non_target = NULL;
@@ -529,12 +571,8 @@ xvc_appdata_validate (XVC_AppData * lapp, int mode, int *rc)
         lapp->flags |= FLG_RUN_VERBOSE;
 
     // start: capture size
-    dpy = xvc_frame_get_capture_display ();
-    max_width = WidthOfScreen (DefaultScreenOfDisplay (dpy));
-    max_height = HeightOfScreen (DefaultScreenOfDisplay (dpy));
-
-    if ((lapp->area->width + lapp->area->x) > max_width ||
-        (lapp->area->height + lapp->area->y) > max_height) {
+    if ((lapp->area->width + lapp->area->x) > lapp->max_width ||
+        (lapp->area->height + lapp->area->y) > lapp->max_height) {
         errors = errorlist_append (6, errors, lapp);
         if (!errors) {
             *rc = -1;
@@ -864,6 +902,7 @@ xvc_appdata_validate (XVC_AppData * lapp, int mode, int *rc)
                 *rc = -1;
                 return NULL;
             }
+
         }
     } else if (lapp->current_mode == 0 && !XVC_FPS_GT_ZERO (target->fps)) {
         errors = errorlist_append (28, errors, lapp);
@@ -1407,7 +1446,7 @@ xvc_appdata_merge_captypeoptions (XVC_CapTypeOptions * cto, XVC_AppData * lapp)
 static void
 error_exit_action (XVC_ErrorListItem * err)
 {
-    exit (1);
+    raise (SIGINT);
 }
 
 /**
@@ -2253,15 +2292,17 @@ errorlist_append (int code, XVC_ErrorListItem * err, XVC_AppData * app)
     XVC_ErrorListItem *new_err, *iterator = NULL, *last = NULL;
     int i, a = -1;
 
-    for (i = 0; xvc_errors[i].code > 0; i++) {
-        if (xvc_errors[i].code == code)
+    for (i = 0; /*xvc_errors[i].code > 0 */ i < NUMERRORS; i++) {
+        if (xvc_errors[i].code == code) {
             a = i;
+            break;
+        }
     }
 
     // could not find error to add to list
     if (a < 0)
         return NULL;
-    new_err = malloc (sizeof (struct _XVC_ErrorListItem));
+    new_err = malloc (sizeof (struct _xvc_ErrorListItem));
     if (!new_err)
         return NULL;
 
@@ -2399,8 +2440,19 @@ xvc_error_write_msg (int code, int print_action_or_not)
 {
     char *type = NULL;
     char scratch[50], buf[5000];
-    const XVC_Error *err = &(xvc_errors[code]);
-    int i, inc, pre = 10, len = 80;
+    const XVC_Error *err;
+    int a = 0, i, inc, pre = 10, len = 80;
+
+    // first we must find the right array element for the error
+    for (i = 0; /*xvc_errors[i].code > 0 */ i < NUMERRORS; i++) {
+        if (xvc_errors[i].code == code) {
+            a = i;
+            break;
+        }
+    }
+    if (a == 0)
+        return;
+    err = &(xvc_errors[a]);
 
     switch (err->type) {
     case 1:
@@ -2533,14 +2585,15 @@ error_write_action_msg (int code)
  *      - 2 : replace number pattern by the number passed as number
  */
 void
-xvc_command_execute (char *command, int flag, int number, char *file,
-                     int fframe, int lframe, int width, int height, XVC_Fps fps)
+xvc_command_execute (const char *command, int flag, int number,
+                     const char *file, int fframe, int lframe, int width,
+                     int height, XVC_Fps fps)
 {
 #define DEBUGFUNCTION "xvc_command_execute()"
 #define BUFLENGTH ((PATH_MAX * 5) + 1)
     char buf[BUFLENGTH];
-    char *myfile = NULL;
-    char *shell = NULL;
+    const char *myfile = NULL;
+    int k;
 
 #ifdef DEBUG
     printf ("%s %s: Entering with flag '%i'\n", DEBUGFILE, DEBUGFUNCTION, flag);
@@ -2552,10 +2605,10 @@ xvc_command_execute (char *command, int flag, int number, char *file,
         break;
     case 1:
         {
-            char file_buf[PATH_MAX + 1], *p;
+            char file_buf[PATH_MAX + 1];
+            const char *p = file;
             int i = 0, n = 0;
 
-            p = file;
             while (*p && (p - file) <= PATH_MAX && (p - file) <= strlen (file)) {
                 if (*p == '%') {
                     p++;
@@ -2597,22 +2650,46 @@ xvc_command_execute (char *command, int flag, int number, char *file,
         break;
     }
 
-    shell = getenv ("SHELL");
-    if (shell) {
-        snprintf (buf, BUFLENGTH,
-                  "%s -c 'XVFFRAME=\"%i\" XVLFRAME=\"%i\" XVWIDTH=\"%i\" XVHEIGHT=\"%i\" XVFPS=\"%f\" XVTIME=\"%f\" XVFILE=\"%s\" ; %s'",
-                  shell, fframe, lframe, width, height,
-                  ((float) fps.num / (float) fps.den),
-                  (float) 1000 / ((float) fps.num / (float) fps.den), myfile,
-                  command);
-    } else {
-        snprintf (buf, BUFLENGTH,
-                  "XVFFRAME=\"%i\" XVLFRAME=\"%i\" XVWIDTH=\"%i\" XVHEIGHT=\"%i\" XVFPS=\"%f\" XVTIME=\"%f\" XVFILE=\"%s\" ; %s",
-                  fframe, lframe, width, height,
-                  ((float) fps.num / (float) fps.den),
-                  (float) 1000 / ((float) fps.num / (float) fps.den), myfile,
-                  command);
+    // add the required environment variables to xvidcap's environment
+    // so the shell spawned inherits them
+    for (k = 0; k < 7; k++) {
+        switch (k) {
+        case 0:
+            snprintf (buf, BUFLENGTH, "%i", fframe);
+            setenv ("XVFFRAME", buf, 1);
+            break;
+        case 1:
+            snprintf (buf, BUFLENGTH, "%i", lframe);
+            setenv ("XVLFRAME", buf, 1);
+            break;
+        case 2:
+            snprintf (buf, BUFLENGTH, "%i", width);
+            setenv ("XVWIDTH", buf, 1);
+            break;
+        case 3:
+            snprintf (buf, BUFLENGTH, "%i", height);
+            setenv ("XVHEIGHT", buf, 1);
+            break;
+        case 4:
+            snprintf (buf, BUFLENGTH,
+                      "%f", ((float) fps.num / (float) fps.den));
+            setenv ("XVFPS", buf, 1);
+            break;
+        case 5:
+            snprintf (buf, BUFLENGTH,
+                      "%f",
+                      ((float) 1000 / ((float) fps.num / (float) fps.den)));
+            setenv ("XVTIME", buf, 1);
+            break;
+        case 6:
+            snprintf (buf, BUFLENGTH, "%s", myfile);
+            setenv ("XVFILE", buf, 1);
+            break;
+        }
     }
+
+    snprintf (buf, BUFLENGTH, "%s", command);
+
 #ifdef DEBUG
     printf ("%s %s: calling: '%s'\n", DEBUGFILE, DEBUGFUNCTION, buf);
 #endif     // DEBUG
@@ -2626,6 +2703,10 @@ xvc_command_execute (char *command, int flag, int number, char *file,
     // sf-edit: flag 2
     // gimp "${XVFILE}" &
 
+    // in case we constructed a filename pattern, we need to free it again
+    if (myfile != file)
+        free ((void *) myfile);
+
 #ifdef DEBUG
     printf ("%s %s: Leaving\n", DEBUGFILE, DEBUGFUNCTION);
 #endif     // DEBUG
@@ -2640,7 +2721,7 @@ xvc_command_execute (char *command, int flag, int number, char *file,
  * @return has pattern TRUE or FALSE
  */
 Boolean
-xvc_is_filename_mutable (char *filename)
+xvc_is_filename_mutable (const char *filename)
 {
     char file[PATH_MAX + 1];
 
@@ -2687,26 +2768,33 @@ xvc_get_number_of_fraction_digits_from_float_string (const char *input)
  * \brief gets the current display and store it in the XVC_AppData struct
  */
 static void
-appdata_set_display ()
+appdata_set_display (XVC_AppData * lapp)
 {
 #define DEBUGFUNCTION "appdata_set_display()"
 #ifdef DEBUG
     printf ("%s %s: Entering with dpy %p\n", DEBUGFILE, DEBUGFUNCTION,
-            app->dpy);
+            lapp->dpy);
 #endif     // DEBUG
 
-    app->dpy = NULL;
-    app->dpy = xvc_frame_get_capture_display ();
-    if (!app->dpy) {
+    lapp->dpy = NULL;
+    lapp->dpy = xvc_frame_get_capture_display ();
+    if (!lapp->dpy) {
         char msg[256];
 
         snprintf (msg, 256, "%s %s: Can't get display to capture from!\n",
                   DEBUGFILE, DEBUGFUNCTION);
         perror (msg);
+        return;
     }
+    lapp->root_window = DefaultRootWindow (lapp->dpy);
+    lapp->default_screen = XDefaultScreenOfDisplay (lapp->dpy);
+    lapp->default_screen_num = XDefaultScreen (lapp->dpy);
+    lapp->max_width = WidthOfScreen (lapp->default_screen);
+    lapp->max_height = HeightOfScreen (lapp->default_screen);
+
 #ifdef DEBUG
     printf ("%s %s: Leaving with dpy %p (%s)\n", DEBUGFILE, DEBUGFUNCTION,
-            app->dpy, DisplayString (app->dpy));
+            lapp->dpy, DisplayString (lapp->dpy));
 #endif     // DEBUG
 #undef DEBUGFUNCTION
 }
@@ -2721,7 +2809,6 @@ void
 xvc_appdata_set_window_attributes (Window win)
 {
 #define DEBUGFUNCTION "xvc_appdata_set_window_attributes()"
-    appdata_set_display ();
-    xvc_get_window_attributes (win, &(app->win_attr));
+    xvc_get_window_attributes (app->dpy, win, &(app->win_attr));
 #undef DEBUGFUNCTION
 }
