@@ -21,8 +21,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ifndef __APP_DATA_H__
-#define __APP_DATA_H__
+#ifndef _xvc_APP_DATA_H__
+#define _xvc_APP_DATA_H__
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 #ifdef HAVE_CONFIG_H
@@ -30,6 +30,9 @@
 #endif
 #include <X11/Intrinsic.h>
 #include "codecs.h"
+#ifdef USE_DBUS
+#include "dbus-server-object.h"
+#endif     // USE_DBUS
 #endif     // DOXYGEN_SHOULD_SKIP_THIS
 
 #define XVC_MAX(a,b) ((a)>(b)? (a):(b))
@@ -89,7 +92,14 @@ enum XVC_Flags
  * extension */
     FLG_USE_XDAMAGE = 2048,
 /** \brief minimize xvidcap to the system tray while recording */
-    FLG_TO_TRAY = 4096
+    FLG_TO_TRAY = 4096,
+/**
+ * \brief this will make the frame follow the mouse when the lock is locked
+ *      rather than have it follow the main control window
+ */
+    FLG_LOCK_FOLLOWS_MOUSE = 8192,
+/** \brief run without frame around the capture area */
+    FLG_NOFRAME = 16384
 };
 
 #ifdef HAVE_SHMAT
@@ -196,6 +206,17 @@ typedef struct
      *      we need it
      */
     Display *dpy;
+    /** \brief the default root window */
+    Window root_window;
+    /** \brief pointer to the default screen */
+    Screen *default_screen;
+    /** \brief default screen number */
+    int default_screen_num;
+    /** \brief maximum width of the default screen */
+    int max_width;
+    /** \brief maximum height of the default screen */
+    int max_height;
+
     /** \brief the area to capture */
     XRectangle *area;
 #ifdef USE_XDAMAGE
@@ -211,6 +232,32 @@ typedef struct
     int default_mode;
     /** \brief the current capture mode, values as with default_mode */
     int current_mode;
+
+    // various mutexes for thread synchonization
+    /** \brief mutex for pausing/unpausing the recording session
+     *		by waiting for the recording_condition_unpaused */
+    pthread_mutex_t recording_paused_mutex;
+    /** \brief condition for pausing/unpausing a recording effectively */
+    pthread_cond_t recording_condition_unpaused;
+    /** \brief mutex for synchronizing state or frame changes with
+     *		capturing of individual frames */
+    pthread_mutex_t capturing_mutex;
+    /** \brief is the recording thread running?
+     *
+     * \todo find out if there's a way to tell that from the tread directly
+     */
+    int recording_thread_running;
+
+#ifdef USE_XDAMAGE
+    /** \brief mutex for the Xdamage support. It governs write access to the
+     *      damaged region storage */
+    pthread_mutex_t damage_regions_mutex;
+#endif     // USE_XDAMAGE
+
+#ifdef USE_DBUS
+    XvcServerObject *xso;
+#endif     // USE_DBUS
+
     /** \brief options for single-frame capture mode */
     XVC_CapTypeOptions single_frame;
     /** \brief options for multi-frame capture mode */
@@ -237,13 +284,13 @@ enum XVC_ErrorType
     XVC_ERR_INFO
 };
 
-struct _XVC_ErrorListItem;
+struct _xvc_ErrorListItem;
 
 /**
  * \brief all information about a given error related to an inconsistency
  *      regarding user preferences is contained here.
  */
-typedef struct _XVC_Error
+typedef struct _xvc_Error
 {
     /** \brief error code */
     const enum XVC_ErrorType code;
@@ -258,7 +305,7 @@ typedef struct _XVC_Error
     /** \brief long description in full sentences */
     const char *long_msg;
     /** \brief default action */
-    void (*action) (struct _XVC_ErrorListItem *);
+    void (*action) (struct _xvc_ErrorListItem *);
     /**
      * \brief describes what the default action does
      *
@@ -283,42 +330,42 @@ extern const XVC_Error xvc_errors[NUMERRORS];
  * \brief wraps an xv_Error in an XVC_ErrorListItem to create a double-linked
  *      list of errors.
  */
-typedef struct _XVC_ErrorListItem
+typedef struct _xvc_ErrorListItem
 {
     /** \brief pointer to actual error */
-    const struct _XVC_Error *err;
+    const struct _xvc_Error *err;
     /** \brief pointer to app_data that threw error */
     XVC_AppData *app;
     /** \brief previous element in the double-linked list */
-    struct _XVC_ErrorListItem *previous;
+    struct _xvc_ErrorListItem *previous;
     /** \brief next element in the double-linked list */
-    struct _XVC_ErrorListItem *next;
+    struct _xvc_ErrorListItem *next;
 } XVC_ErrorListItem;
 
 /*
  * Functions from app_data.c
  */
-void xvc_appdata_free ();
+void xvc_appdata_free (XVC_AppData * lapp);
 XVC_AppData *xvc_appdata_ptr (void);
 void xvc_appdata_init (XVC_AppData * lapp);
 void xvc_appdata_set_defaults (XVC_AppData * lapp);
-void xvc_appdata_copy (XVC_AppData * tapp, XVC_AppData * sapp);
+void xvc_appdata_copy (XVC_AppData * tapp, const XVC_AppData * sapp);
 void xvc_appdata_merge_captypeoptions (XVC_CapTypeOptions * cto,
                                        XVC_AppData * lapp);
 XVC_ErrorListItem *xvc_appdata_validate (XVC_AppData * lapp, int mode, int *rc);
 void xvc_appdata_set_window_attributes (Window win);
 
 void xvc_captypeoptions_copy (XVC_CapTypeOptions * topts,
-                              XVC_CapTypeOptions * sopts);
+                              const XVC_CapTypeOptions * sopts);
 void xvc_captypeoptions_init (XVC_CapTypeOptions * cto);
 
 XVC_ErrorListItem *xvc_errorlist_delete (XVC_ErrorListItem * err);
 void xvc_error_write_msg (int code, int print_action_or_not);
 
-Boolean xvc_is_filename_mutable (char *);
+Boolean xvc_is_filename_mutable (const char *);
 int xvc_get_number_of_fraction_digits_from_float_string (const char *input);
-void xvc_command_execute (char *command, int flag, int number, char *file,
-                          int fframe, int lframe, int width, int height,
-                          XVC_Fps fps);
+void xvc_command_execute (const char *command, int flag, int number,
+                          const char *file, int fframe, int lframe, int width,
+                          int height, XVC_Fps fps);
 
-#endif     // __APP_DATA_H__
+#endif     // _xvc_APP_DATA_H__
