@@ -46,6 +46,7 @@
 #include <sys/time.h>
 #include <time.h>
 #include <unistd.h>
+#include <pthread.h>
 
 #include <X11/X.h>
 #include <X11/Xlib.h>
@@ -56,12 +57,18 @@
 #ifdef HAVE_LIBXFIXES
 #include <X11/extensions/Xfixes.h>
 #endif     // HAVE_LIBXFIXES
+#ifdef USE_XDAMAGE
+#include <X11/Xregion.h>
+#include <X11/Xutil.h>
+#endif     // USE_XDAMAGE
 #ifdef HAVE_SHMAT
 #include <sys/ipc.h>
 #include <sys/shm.h>
 #include <X11/extensions/XShm.h>
 #include <X11/extensions/shmstr.h>
+#ifndef SOLARIS
 #include <X11/extensions/extutil.h>
+#endif     // SOLARIS
 
 #endif     // HAVE_SHMAT
 #ifdef HasDGA
@@ -75,15 +82,21 @@
 #include "video.h"
 #endif     // HasVideo4Linux
 
+#include <errno.h>
+
 #include "capture.h"
 #include "job.h"
 #include "app_data.h"
 #include "control.h"
+#include "frame.h"
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 extern int xvc_led_time;
 #endif     // DOXYGEN_SHOULD_SKIP_THIS
 
+/** \brief make error numbers accessible */
+extern int errno;
+
 #ifdef HAVE_LIBXFIXES
 /** \brief we need to get color information for processing the real mouse
  *      pointer. */
@@ -96,6 +109,13 @@ static unsigned char top[65536];
 static unsigned char bottom[65536];
 #endif     // HAVE_LIBXFIXES
 
+#ifdef USE_XDAMAGE
+/** \brief each captured frame saves its mouse pointer information for
+    the next frame to find it. This is only required in the context
+    of Xdamage */
+static XRectangle pointer_area;
+#endif     // USE_XDAMAGE
+
 /**
  * \brief function to find out where the mouse pointer is
  *
@@ -106,23 +126,43 @@ static void
 getCurrentPointer (int *x, int *y)
 {
 #define DEBUGFUNCTION "getCurrentPointer()"
-    Window mrootwindow, childwindow;
+    Window childwindow;
     int dummy;
     XVC_AppData *app = xvc_appdata_ptr ();
 
-    mrootwindow = DefaultRootWindow (app->dpy);
-
-    if (!XQueryPointer (app->dpy, mrootwindow, &mrootwindow, &childwindow,
-                        x, y, &dummy, &dummy, (unsigned int *) &dummy)) {
+    if (!XQueryPointer (app->dpy, app->root_window, &(app->root_window),
+                        &childwindow, x, y, &dummy, &dummy,
+                        (unsigned int *) &dummy)) {
         fprintf (stderr,
                  "%s %s: couldn't find mouse pointer for disp: %p , rootwindow: %p\n",
-                 DEBUGFILE, DEBUGFUNCTION, app->dpy, &mrootwindow);
+                 DEBUGFILE, DEBUGFUNCTION, app->dpy, &(app->root_window));
         *x = -1;
         *y = -1;
     }
 #undef DEBUGFUNCTION
 }
 
+#ifdef HAVE_LIBXFIXES
+/**
+ * \brief function to return mouse pointer shape.
+ *      This is only used with XFixes. Previously we did this inside
+ *      paintMousePointer. I've split this to be able to do the getting inside
+ *      a lock and the painting outside it.
+ *
+ * @return a pointer to an XFixesCursorImage for the current pointer
+ */
+static XFixesCursorImage *
+getCurrentPointerImage ()
+{
+    XVC_AppData *app = xvc_appdata_ptr ();
+    XFixesCursorImage *x_cursor = NULL;
+
+    x_cursor = XFixesGetCursorImage (app->dpy);
+
+    return x_cursor;
+}
+#endif     // HAVE_LIBXFIXES
+
 /**
  * Mouse painting helper function that applies an 'and' and 'or' mask pair to
  * '*dst' pixel. It actually draws a mouse pointer pixel to grabbed frame.
@@ -167,13 +207,52 @@ count_one_bits (long bits)
     return res;
 }
 
+#ifdef USE_XDAMAGE
 /**
  * \brief Paints a mouse pointer in an X11 image.
+ *      This is the version for use without xfixes or xdamage
  *
  * @param image Image where to paint the mouse pointer
+ * @param my_x_cursor pointer to the XFixesCursorImage of the captured mouse
+ *      pointer. If a dummy mouse pointer is wanted, unset FLG_USE_XFIXES in
+ *      app->flags, and pass x and y
+ * @param x the x position of the pointer. Only needed if !FLG_USE_XFIXES.
+ * @param y the y position of the pointer. Only needed if !FLG_USE_XFIXES.
+ * @return an XRectangle for Xdamage to know which area to repair in the next
+ *      frame.
  */
 static XRectangle
-paintMousePointer (XImage * image)
+paintMousePointer (XImage * image, XFixesCursorImage * my_x_cursor, int x,
+                   int y)
+#else      // USE_XDAMAGE
+#ifdef HAVE_LIBXFIXES
+/**
+ * \brief Paints a mouse pointer in an X11 image.
+ *      This is the version for use without xfixes or xdamage
+ *
+ * @param image Image where to paint the mouse pointer
+ * @param my_x_cursor pointer to the XFixesCursorImage of the captured mouse
+ *      pointer. If a dummy mouse pointer is wanted, unset FLG_USE_XFIXES in
+ *      app->flags, and pass x and y
+ * @param x the x position of the pointer. Only needed if !FLG_USE_XFIXES.
+ * @param y the y position of the pointer. Only needed if !FLG_USE_XFIXES.
+ */
+static void
+paintMousePointer (XImage * image, XFixesCursorImage * my_x_cursor, int x,
+                   int y)
+#else      //HAVE_LIBXFIXES
+/**
+ * \brief Paints a mouse pointer in an X11 image.
+ *      This is the version for use without xfixes or xdamage
+ *
+ * @param image Image where to paint the mouse pointer
+ * @param x the x position of the pointer
+ * @param y the y position of the pointer
+ */
+static void
+paintMousePointer (XImage * image, int x, int y)
+#endif     // HAVE_LIBXFIXES
+#endif     // USE_XDAMAGE
 {
 #define DEBUGFUNCTION "paintMousePointer()"
     /* 16x20x1bpp bitmap for the black channel of the mouse pointer */
@@ -192,15 +271,14 @@ paintMousePointer (XImage * image)
         0x00C0, 0x0180, 0x0180, 0x0000, 0x0000
     };
 
-    int x, y, cursor_width = 16, cursor_height = 20;
+    int cursor_width = 16, cursor_height = 20;
     XVC_AppData *app = xvc_appdata_ptr ();
     Job *job = xvc_job_ptr ();
-    XRectangle pArea;
+    XRectangle pArea = { 0, 0, 0, 0 };
 
 #ifdef HAVE_LIBXFIXES
     unsigned char topp, botp;
     unsigned long applied;
-    XFixesCursorImage *x_cursor = NULL;
 #endif     // HAVE_LIBXFIXES
 
     // only paint a mouse pointer into the dummy frame if the position of
@@ -208,18 +286,25 @@ paintMousePointer (XImage * image)
 
 #ifdef HAVE_LIBXFIXES
     if (app->flags & FLG_USE_XFIXES) {
-        x_cursor = XFixesGetCursorImage (app->dpy);
-        cursor_width = x_cursor->width;
-        cursor_height = x_cursor->height;
-        y = x_cursor->y - x_cursor->yhot;
-        x = x_cursor->x - x_cursor->xhot;
-    } else {
-        getCurrentPointer (&x, &y);
+#ifdef USE_XDAMAGE
+        // if we use xfixes, we want a cursor image
+        if (!my_x_cursor) {
+            return pArea;
+        }
+#else      // USE_XDAMAGE
+        if (!my_x_cursor)
+            return;
+#endif     // USE_XDAMAGE
+        // set cursor dimensions from cursor image
+        cursor_width = my_x_cursor->width;
+        cursor_height = my_x_cursor->height;
+        y = my_x_cursor->y - my_x_cursor->yhot;
+        x = my_x_cursor->x - my_x_cursor->xhot;
     }
-#else
-    getCurrentPointer (&x, &y);
 #endif     // HAVE_LIBXFIXES
 
+    // only paint a mouse pointer into the dummy frame if the position of
+    // the mouse is within the rectangle defined by the capture frame
     if ((x - app->area->x + cursor_width) >= 0 &&
         x < (app->area->width + app->area->x) &&
         (y - app->area->y + cursor_height) >= 0 &&
@@ -261,7 +346,7 @@ paintMousePointer (XImage * image)
 
 #ifdef HAVE_LIBXFIXES
             if (app->flags & FLG_USE_XFIXES)
-                pix_pointer = (line * x_cursor->width) + x_cursor->pixels;
+                pix_pointer = (line * my_x_cursor->width) + my_x_cursor->pixels;
 #endif     // HAVE_LIBXFIXES
 
             if (!app->flags & FLG_USE_XFIXES) {
@@ -469,15 +554,18 @@ paintMousePointer (XImage * image)
 
             im_data += image->bytes_per_line;
         }
+
+        // return the are covered by the mouse pointer
+        pArea.x = x;
+        pArea.y = y;
+        pArea.width = cursor_width;
+        pArea.height = cursor_height;
+    } else {
+        // otherwise return an empty area
+        pArea.x = pArea.y = pArea.width = pArea.height = 0;
     }
 
-    pArea.x = x;
-    pArea.y = y;
-    pArea.width = cursor_width;
-    pArea.height = cursor_height;
-
     return pArea;
-
 #undef DEBUGFUNCTION
 }
 
@@ -687,11 +775,11 @@ getOutputFile ()
         sprintf (file, job->file, job->pic_no);
     }
 
+#ifdef DEBUG
+    printf ("%s %s: Trying to open file %s\n", DEBUGFILE, DEBUGFUNCTION, file);
+#endif     // DEBUG
+
     fp = fopen (file, "wb");
-    if (!fp) {
-        perror (file);
-        job->state = VC_STOP;
-    }
 
     return fp;
 #undef DEBUGFUNCTION
@@ -712,17 +800,38 @@ captureFrameToImage (Display * dpy, XImage * image)
     int ret = 0;
     XVC_AppData *app = xvc_appdata_ptr ();
 
+#ifdef USE_XDAMAGE
+    Region damaged_region = NULL;
+#endif     // USE_XDAMAGE
+
 #ifdef DEBUG
     printf ("%s %s: Entering\n", DEBUGFILE, DEBUGFUNCTION);
 #endif     // DEBUG
 
+#ifdef USE_XDAMAGE
+    // if we use Xdamage and are still capturing a complete frame (which is
+    // what we're doing here, then we can discard the regions damaged up to
+    // now
+    if (app->flags & FLG_USE_XDAMAGE) {
+        // get the damage up to now
+        // we're assuming we're on a locked and synched display
+        damaged_region = xvc_get_damage_region ();
+    }
+#endif     // USE_XDAMAGE
+
     // get the image here
-    if (XGetZPixmapToXImage (dpy,
-                             RootWindow (dpy, DefaultScreen (dpy)),
+    if (XGetZPixmapToXImage (dpy, app->root_window,
                              image, app->area->x, app->area->y)) {
         // paint the mouse pointer into the captured image if necessary
         ret = 1;
     }
+#ifdef USE_XDAMAGE
+    if (app->flags & FLG_USE_XDAMAGE) {
+        // and discard the damage
+        XDestroyRegion (damaged_region);
+    }
+#endif     // USE_XDAMAGE
+
 #ifdef DEBUG
     printf ("%s %s: Leaving\n", DEBUGFILE, DEBUGFUNCTION);
 #endif     // DEBUG
@@ -761,7 +870,7 @@ createImage (Display * dpy, int width, int height)
  * need XInitImage
  */
 
-    image = XGetImage (dpy, RootWindow (dpy, DefaultScreen (dpy)),
+    image = XGetImage (dpy, app->root_window,
                        app->area->x, app->area->y,
                        app->area->width, app->area->height, AllPlanes, ZPixmap);
     g_assert (image);
@@ -792,7 +901,7 @@ captureFrameCreatingImage (Display * dpy)
 #endif     // DEBUG
 
     // get the image here
-    image = XGetImage (dpy, RootWindow (dpy, DefaultScreen (dpy)),
+    image = XGetImage (dpy, app->root_window,
                        app->area->x, app->area->y,
                        app->area->width, app->area->height, AllPlanes, ZPixmap);
     if (!image) {
@@ -825,17 +934,39 @@ captureFrameToImageSHM (Display * dpy, XImage * image)
     int ret = 0;
     XVC_AppData *app = xvc_appdata_ptr ();
 
+#ifdef USE_XDAMAGE
+    Region damaged_region = NULL;
+#endif     // USE_XDAMAGE
+
 #ifdef DEBUG
     printf ("%s %s: Entering\n", DEBUGFILE, DEBUGFUNCTION);
 #endif     // DEBUG
 
+#ifdef USE_XDAMAGE
+    // if we use Xdamage and are still capturing a complete frame (which is
+    // what we're doing here, then we can discard the regions damaged up to
+    // now
+    if (app->flags & FLG_USE_XDAMAGE) {
+        // get the damage up to now
+        // we're assuming we're on a locked and synched display
+        damaged_region = xvc_get_damage_region ();
+    }
+#endif     // USE_XDAMAGE
+
     // get the image here
     if (XShmGetImage (dpy,
-                      RootWindow (dpy, DefaultScreen (dpy)),
+                      app->root_window,
                       image, app->area->x, app->area->y, AllPlanes)) {
         // paint the mouse pointer into the captured image if necessary
         ret = 1;
     }
+#ifdef USE_XDAMAGE
+    if (app->flags & FLG_USE_XDAMAGE) {
+        // discard the damage
+        XDestroyRegion (damaged_region);
+    }
+#endif     // USE_XDAMAGE
+
 #ifdef DEBUG
     printf ("%s %s: Leaving\n", DEBUGFILE, DEBUGFUNCTION);
 #endif     // DEBUG
@@ -980,6 +1111,7 @@ checkCaptureDuration (long time, long time1)
             printf
                 ("missing %ld milli secs (%d needed per frame), pic no %d\n",
                  time, job->time_per_frame, job->pic_no);
+        time = 0;
     }
 
     return time;
@@ -999,20 +1131,27 @@ commonCapture (enum captureFunctions capfunc)
 #define DEBUGFUNCTION "commonCapture()"
     static XImage *image = NULL;
     static FILE *fp = NULL; // file handle to write the frame to
-    long time, time1;   /* for measuring the duration of a frame capture */
+    long time = 0, time1;   /* for measuring the duration of a frame capture */
     struct timeval curr_time;   /* for measuring the duration of a frame
                                  * capture */
     static int shm_opcode = 0, shm_event_base = 0, shm_error_base = 0;
-    static XRectangle pointer_area;
+
+//    static XRectangle pointer_area;
 
     XVC_AppData *app = xvc_appdata_ptr ();
     XVC_CapTypeOptions *target;
     Job *job = xvc_job_ptr ();
+    int full_cleanup = TRUE;
+    int frame_moved = FALSE;
+    int pointer_x = 0, pointer_y = 0;
+
+#ifdef HAVE_LIBXFIXES
+    XFixesCursorImage *x_cursor = NULL;
+#endif     // HAVE_LIBXFIXES
 
 #ifdef USE_XDAMAGE
-    XserverRegion damaged_region;
+    Region damaged_region;
     static XImage *dmg_image = NULL;
-    static XserverRegion region = None, clip_region = None;
 
 #ifdef HAVE_SHMAT
     static XShmSegmentInfo dmg_shminfo;
@@ -1035,6 +1174,50 @@ commonCapture (enum captureFunctions capfunc)
 #endif     // USE_FFMPEG
         target = &(app->single_frame);
 
+    // we really cannot have external state changes
+    // while we're reacting on state
+    // frame moves, too, are evil
+    pthread_mutex_lock (&(app->capturing_mutex));
+
+    // if the frame has moved during capture, move it here
+    if (job->frame_moved_x != 0 || job->frame_moved_y != 0) {
+        xvc_frame_change (app->area->x + job->frame_moved_x,
+                          app->area->y + job->frame_moved_y,
+                          app->area->width, app->area->height, FALSE, FALSE);
+        frame_moved = TRUE;
+        job->frame_moved_x = job->frame_moved_y = 0;
+        // make sure the frame is actually moved before continuing with the
+        // capture to avoid capturing the frame (this is not a guarantee with
+        // compositing window managers, though)
+        XSync (app->dpy, False);
+    } else if ((app->flags & FLG_LOCK_FOLLOWS_MOUSE) != 0 &&
+               xvc_is_frame_locked ()) {
+        int px = 0, py = 0;
+        int x = app->area->x, y = app->area->y;
+        int width = app->area->width, height = app->area->height;
+
+        getCurrentPointer (&px, &py);
+
+        if (px > (app->area->x + ((app->area->width * 9) / 10))) {
+            x = px - ((app->area->width * 9) / 10);
+            frame_moved = TRUE;
+        } else if (px < (app->area->x + (app->area->width / 10))) {
+            x = px - (app->area->width / 10);
+            frame_moved = TRUE;
+        }
+        if (py > (app->area->y + ((app->area->height * 9) / 10))) {
+            y = py - ((app->area->height * 9) / 10);
+            frame_moved = TRUE;
+        } else if (py < (app->area->y + (app->area->height / 10))) {
+            y = py - (app->area->height / 10);
+            frame_moved = TRUE;
+        }
+
+        if (frame_moved) {
+            xvc_frame_change (x, y, width, height, FALSE, FALSE);
+            XSync (app->dpy, False);
+        }
+    }
     // wait for next iteration if pausing
     if (job->state & VC_REC) {         // if recording ...
 
@@ -1061,8 +1244,8 @@ commonCapture (enum captureFunctions capfunc)
             // autocontinue on we're setting a flag to let the cleanup
             // code know we need
             // to restart again afterwards
-            if (app->flags & FLG_AUTO_CONTINUE) {
-                xvc_job_merge_state (VC_CONTINUE);
+            if (job->flags & FLG_AUTO_CONTINUE) {
+                job->state |= VC_CONTINUE;
             }
 
             goto CLEAN_CAPTURE;
@@ -1078,24 +1261,46 @@ commonCapture (enum captureFunctions capfunc)
             (app->current_mode > 0 && job->state & VC_START)) {
 
 #ifdef DEBUG
-            printf ("%s %s: opening file for captured frame(s)\n",
-                    DEBUGFILE, DEBUGFUNCTION);
+            printf ("%s %s: opening file for captured frame(s) ... state %i\n",
+                    DEBUGFILE, DEBUGFUNCTION, job->state);
 #endif     // DEBUG
 
             fp = getOutputFile ();
-            if (!fp)
-                return FALSE;
+#ifdef DEBUG
+            printf ("%s %s: got this file pointer %p\n",
+                    DEBUGFILE, DEBUGFUNCTION, fp);
+#endif     // DEBUG
+            if (!fp) {
+                // we react on errno when cleaning up
+                job->capture_returned_errno = errno;
+                // we may or may not need a full cleanup (for movie we need
+                // one only if we have actually started, i. e. proceeded
+                // beyond frame 0
+                if (app->current_mode > 0 || job->pic_no == target->start_no)
+                    full_cleanup = FALSE;
+                goto CLEAN_CAPTURE;
+            }
         }
         // if this is the first frame for the current job ...
         if (job->state & VC_START) {
 
+            // the next bit is true if we have configured max_frames and we're
+            // reaching the limit with this captured frame
+            // this should not at all be possible with this, the first frame
+            if (target->frames && ((job->pic_no - target->start_no) >
+                                   target->frames - 1)) {
+                full_cleanup = FALSE;
+                goto CLEAN_CAPTURE;
+            }
 #ifdef DEBUG
             printf ("%s %s: create data structure for image\n", DEBUGFILE,
                     DEBUGFUNCTION);
 #endif     // DEBUG
 
 #ifdef HAVE_LIBXFIXES
-            if (app->flags & FLG_USE_XFIXES) {
+            // if we use xfixes, we need this for alpha blending of the mouse
+            // pointer
+            if (app->flags & FLG_USE_XFIXES && app->mouseWanted > 0) {
                 unsigned int mask, color;
 
                 for (mask = 0; mask <= 255; mask++) {
@@ -1108,24 +1313,24 @@ commonCapture (enum captureFunctions capfunc)
             }
 #endif     // HAVE_LIBXFIXES
 
-#ifdef USE_XDAMAGE
+#ifdef USE_XDAMAGE_NONE
             if (app->flags & FLG_USE_XDAMAGE) {
-                // get the damaged region
-                // stuff damaged between starting the damage poll thread and
-                // this (capture of the first frame) ... we can safely discard
-                // the damage
-                damaged_region = xvc_get_damage_region ();
-                XFixesDestroyRegion (app->dpy, damaged_region);
+                // create some utility regions
                 region = XFixesCreateRegion (app->dpy, 0, 0);
                 clip_region = XFixesCreateRegion (app->dpy, 0, 0);
             }
 #endif     // USE_XDAMAGE
 
+            // lock the display for consistency
+            XLockDisplay (app->dpy);
+
+            // capture the start frame with whatever function applicable
             switch (capfunc) {
 #ifdef HAVE_SHMAT
             case SHM:
                 image = captureFrameCreatingImageSHM (app->dpy, &shminfo);
 #ifdef USE_XDAMAGE
+                // also initialize xdamage stuff
                 if (app->flags & FLG_USE_XDAMAGE) {
                     XQueryExtension (app->dpy, "MIT-SHM", &shm_opcode,
                                      &shm_event_base, &shm_error_base);
@@ -1140,6 +1345,7 @@ commonCapture (enum captureFunctions capfunc)
             default:
                 image = captureFrameCreatingImage (app->dpy);
 #ifdef USE_XDAMAGE
+                // also initialize xdamage stuff
                 if (app->flags & FLG_USE_XDAMAGE) {
                     dmg_image = createImage (app->dpy, app->area->width,
                                              app->area->height);
@@ -1147,6 +1353,17 @@ commonCapture (enum captureFunctions capfunc)
 #endif     // USE_XDAMAGE
             }
 
+            if (app->mouseWanted > 0) {
+#ifdef HAVE_LIBXFIXES
+                if (app->flags & FLG_USE_XFIXES)
+                    x_cursor = getCurrentPointerImage ();
+                else
+#endif     // HAVE_LIBXFIXES
+                    getCurrentPointer (&pointer_x, &pointer_y);
+            }
+            // now, we have captured all we need and can unlock the display
+            XUnlockDisplay (app->dpy);
+
             // need to determine c_info from image FIRST
             if (!(job->c_info))
                 job->c_info = xvc_get_color_info (image);
@@ -1154,14 +1371,35 @@ commonCapture (enum captureFunctions capfunc)
             // now we can draw the mouse pointer
             if (image) {
                 if (app->mouseWanted > 0) {
-                    pointer_area = paintMousePointer (image);
+#ifdef USE_XDAMAGE
+                    if (app->flags & FLG_USE_XFIXES)
+                        pointer_area =
+                            paintMousePointer (image, x_cursor, 0, 0);
+                    else
+                        pointer_area = paintMousePointer (image, NULL,
+                                                          pointer_x, pointer_y);
+#else      // USE_XDAMAGE
+#ifdef HAVE_LIBXFIXES
+                    if (app->flags & FLG_USE_XFIXES)
+                        paintMousePointer (image, x_cursor, 0, 0);
+                    else
+                        paintMousePointer (image, NULL, pointer_x, pointer_y);
+#else      // HAVE_LIBXFIXES
+                    paintMousePointer (image, pointer_x, pointer_y);
+#endif     // HAVE_LIBXFIXES
+#endif     // USE_XDAMAGE
                 }
+                // we can allow state or frame changes after this
+                pthread_mutex_unlock (&(app->capturing_mutex));
                 // call the necessary XtoXYZ function to process the image
                 (*job->save) (fp, image);
-                xvc_job_remove_state (VC_START);
-            } else
+                job->state &= ~(VC_START);
+            } else {
+                // we can allow state or frame changes after this
+                pthread_mutex_unlock (&(app->capturing_mutex));
                 printf ("%s %s: could not acquire pixmap!\n", DEBUGFILE,
                         DEBUGFUNCTION);
+            }
         } else {
             // we're recording and not in the first frame ....
             // so we just read new data into the present image structure
@@ -1170,49 +1408,87 @@ commonCapture (enum captureFunctions capfunc)
                     DEBUGFILE, DEBUGFUNCTION);
 #endif     // DEBUG
 #ifdef USE_XDAMAGE
-            if (app->flags & FLG_USE_XDAMAGE) {
+            if (app->flags & FLG_USE_XDAMAGE && !frame_moved) {
                 int num_dmg_rects, rcount;
-                XRectangle *dmg_rects;
+                Box *dmg_rects;
 
+                // then lock the display so we capture a consitent state
+                XLockDisplay (app->dpy);
+                // sync the display
+                XSync (app->dpy, False);
+                // first get the consolidated region where stuff was damaged
+                // since the last frame
                 damaged_region = xvc_get_damage_region ();
+                // add the last position of the mouse pointer to the damaged
+                // region
                 if (app->mouseWanted > 0) {
-                    XFixesSetRegion (app->dpy, region, &(pointer_area), 1);
-                    XFixesSetRegion (app->dpy, clip_region, app->area, 1);
+                    // clip pointer_area to capture area
+                    // this needs to be done here, because the captuer area
+                    // might have been moved since the last frame
+                    if (pointer_area.x < app->area->x &&
+                        (pointer_area.x + pointer_area.width) > app->area->x) {
+                        pointer_area.width -= (app->area->x - pointer_area.x);
+                        pointer_area.x = app->area->x;
+                    }
+                    if ((pointer_area.x + pointer_area.width) >
+                        (app->area->x + app->area->width)) {
+                        pointer_area.width =
+                            (app->area->x + app->area->width) - pointer_area.x;
+                    }
+                    if (pointer_area.y < app->area->y &&
+                        (pointer_area.y + pointer_area.height) > app->area->y) {
+                        pointer_area.height -= (app->area->y - pointer_area.y);
+                        pointer_area.y = app->area->y;
+                    }
+                    if ((pointer_area.y + pointer_area.height) >
+                        (app->area->y + app->area->height)) {
+                        pointer_area.height =
+                            (app->area->y + app->area->height) - pointer_area.y;
+                    }
+                    if (!
+                        ((pointer_area.x + pointer_area.width) < app->area->x
+                         || pointer_area.x > (app->area->x + app->area->width)
+                         || (pointer_area.y + pointer_area.height) <
+                         app->area->y
+                         || pointer_area.y >
+                         (app->area->y + app->area->height))) {
+                        XUnionRectWithRegion (&(pointer_area), damaged_region,
+                                              damaged_region);
+                    }
 
-                    XFixesIntersectRegion (app->dpy, region, region,
-                                           clip_region);
-                    XFixesUnionRegion (app->dpy, damaged_region, damaged_region,
-                                       region);
                 }
-                dmg_rects = XFixesFetchRegion (app->dpy, damaged_region,
-                                               &num_dmg_rects);
+                // get individual rectangles from the damaged region
+                dmg_rects = damaged_region->rects;
+                num_dmg_rects = damaged_region->numRects;
 
-//            if (num_dmg_rects > 0) XSync(app->dpy, False);
+                // then iterate across them and capture the content of the
+                // rectangles
                 for (rcount = 0; rcount < num_dmg_rects; rcount++) {
                     int bpl;
+                    int x =
+                        XVC_MIN (dmg_rects[rcount].x1, dmg_rects[rcount].x2);
+                    int y =
+                        XVC_MIN (dmg_rects[rcount].y1, dmg_rects[rcount].y2);
+                    int width =
+                        abs (dmg_rects[rcount].x1 - dmg_rects[rcount].x2);
+                    int height =
+                        abs (dmg_rects[rcount].y1 - dmg_rects[rcount].y2);
 
+                    // either x11 or shm source
                     switch (capfunc) {
 #ifdef HAVE_SHMAT
                     case SHM:
                         XGetZPixmapSHM (app->dpy,
-                                        RootWindow (app->dpy,
-                                                    DefaultScreen (app->dpy)),
+                                        app->root_window,
                                         &dmg_shminfo, shm_opcode,
-                                        dmg_image->data, dmg_rects[rcount].x,
-                                        dmg_rects[rcount].y,
-                                        dmg_rects[rcount].width,
-                                        dmg_rects[rcount].height);
+                                        dmg_image->data, x, y, width, height);
                         break;
 #endif     // HAVE_SHMAT
                     case X11:
                     default:
                         XGetZPixmap (app->dpy,
-                                     RootWindow (app->dpy,
-                                                 DefaultScreen (app->dpy)),
-                                     dmg_image->data, dmg_rects[rcount].x,
-                                     dmg_rects[rcount].y,
-                                     dmg_rects[rcount].width,
-                                     dmg_rects[rcount].height);
+                                     app->root_window,
+                                     dmg_image->data, x, y, width, height);
                     }
                     /* the following assumes lines in images retrieved from
                      * X11 will always be aligned to 4-byte boundaries. You
@@ -1220,31 +1496,51 @@ commonCapture (enum captureFunctions capfunc)
                      * member of an XImage. However, for performance reasons,
                      * we do not always retrieve a complete XImage. */
                     bpl =
-                        ((dmg_rects[rcount].width *
-                          (image->bits_per_pixel >> 3)) % 4 >
-                         0
-                         ? ((dmg_rects[rcount].width *
-                             (image->bits_per_pixel >> 3)) / 4) * 4 +
-                         4 : dmg_rects[rcount].width *
-                         (image->bits_per_pixel >> 3)
-                        );
+                        ((width * (image->bits_per_pixel >> 3)) % 4 > 0 ?
+                         ((width * (image->bits_per_pixel >> 3)) / 4) * 4 + 4 :
+                         width * (image->bits_per_pixel >> 3));
+                    // update the content of the damaged areas in the frame
+                    // to encode
                     placeImageInImage (dmg_image->data,
-                                       dmg_rects[rcount].x - app->area->x,
-                                       dmg_rects[rcount].y - app->area->y,
-                                       dmg_rects[rcount].width,
+                                       x - app->area->x,
+                                       y - app->area->y,
+                                       width,
                                        bpl,
-                                       dmg_rects[rcount].height, image->data,
+                                       height, image->data,
                                        image->width,
                                        image->bytes_per_line,
                                        image->height,
                                        image->bits_per_pixel >> 3);
                 }
-                if (num_dmg_rects > 0) {
-                    XFree (dmg_rects);
+                // save the current mouse pointer location for further
+                // reference during capture of next frame, only get it here
+                // for minimizing locking
+                if (app->mouseWanted > 0) {
+#ifdef HAVE_LIBXFIXES
+                    if (app->flags & FLG_USE_XFIXES)
+                        x_cursor = getCurrentPointerImage ();
+                    else
+#endif     // HAVE_LIBXFIXES
+                        getCurrentPointer (&pointer_x, &pointer_y);
                 }
-                XFixesDestroyRegion (app->dpy, damaged_region);
+                // now we can release the lock on the display again
+                XUnlockDisplay (app->dpy);
+
+                // paint the mouse pointer here, outside the lock
+#ifdef HAVE_LIBXFIXES
+                if (app->flags & FLG_USE_XFIXES)
+                    pointer_area = paintMousePointer (image, x_cursor, 0, 0);
+                else
+#endif     // HAVE_LIBXFIXES
+                    pointer_area = paintMousePointer (image, NULL, pointer_x,
+                                                      pointer_y);
+                XDestroyRegion (damaged_region);
             } else {
 #endif     // USE_XDAMAGE
+
+                // lock the display for consistency
+                XLockDisplay (app->dpy);
+
                 switch (capfunc) {
 #ifdef HAVE_SHMAT
                 case SHM:
@@ -1255,14 +1551,43 @@ commonCapture (enum captureFunctions capfunc)
                 default:
                     captureFrameToImage (app->dpy, image);
                 }
+                if (app->mouseWanted > 0) {
+#ifdef HAVE_LIBXFIXES
+                    if (app->flags & FLG_USE_XFIXES)
+                        x_cursor = getCurrentPointerImage ();
+                    else
+#endif     // HAVE_LIBXFIXES
+                        getCurrentPointer (&pointer_x, &pointer_y);
+                }
+                // unlock display again
+                XUnlockDisplay (app->dpy);
 
+                if (app->mouseWanted > 0) {
+#ifdef USE_XDAMAGE
+                    if (app->flags & FLG_USE_XFIXES)
+                        pointer_area =
+                            paintMousePointer (image, x_cursor, 0, 0);
+                    else
+                        pointer_area = paintMousePointer (image, NULL,
+                                                          pointer_x, pointer_y);
+#else      // USE_XDAMAGE
+#ifdef HAVE_LIBXFIXES
+                    if (app->flags & FLG_USE_XFIXES)
+                        paintMousePointer (image, x_cursor, 0, 0);
+                    else
+                        paintMousePointer (image, NULL, pointer_x, pointer_y);
+#else      // HAVE_LIBXFIXES
+                    paintMousePointer (image, pointer_x, pointer_y);
+#endif     // HAVE_LIBXFIXES
+#endif     // USE_XDAMAGE
+                }
 #if USE_XDAMAGE
             }
 #endif     // USE_XDAMAGE
 
-            if (app->mouseWanted > 0) {
-                pointer_area = paintMousePointer (image);
-            }
+            // we can allow state or frame changes after this
+            pthread_mutex_unlock (&(app->capturing_mutex));
+
             // call the necessary XtoXYZ function to process the image
             (*job->save) (fp, image);
         }
@@ -1297,7 +1622,7 @@ commonCapture (enum captureFunctions capfunc)
         // this might be a single step. If so, remove the state flag so we
         // don't keep single stepping
         if (job->state & VC_STEP) {
-            xvc_job_remove_state (VC_STEP);
+            job->state &= ~(VC_STEP);
             // the time is the pause between this and the next snapshot
             // for step mode this makes no sense and could be 0. Setting
             // it to 50 is just to give the led meter the chance to flash
@@ -1319,33 +1644,36 @@ commonCapture (enum captureFunctions capfunc)
 
         time = 0;
         orig_state = job->state;       // store state here, esp. VC_CONTINUE
+        job->state = VC_STOP;
+        // we can allow state or frame changes after this
+        pthread_mutex_unlock (&(app->capturing_mutex));
 
-        if (image) {
-            XDestroyImage (image);
-            image = NULL;
-        }
-        if (capfunc == SHM)
-            XShmDetach (app->dpy, &shminfo);
+        if (full_cleanup) {
+            if (image) {
+                XDestroyImage (image);
+                image = NULL;
+            }
+            if (capfunc == SHM)
+                XShmDetach (app->dpy, &shminfo);
 
 #ifdef USE_XDAMAGE
-        if (app->flags & FLG_USE_XDAMAGE) {
-            if (capfunc == SHM)
-                XShmDetach (app->dpy, &dmg_shminfo);
-            if (dmg_image)
-                XDestroyImage (dmg_image);
-        }
+            if (app->flags & FLG_USE_XDAMAGE) {
+                if (capfunc == SHM)
+                    XShmDetach (app->dpy, &dmg_shminfo);
+                if (dmg_image)
+                    XDestroyImage (dmg_image);
+            }
 #endif     // USE_XDAMAGE
 
-        xvc_job_set_state (VC_STOP);
-
+            // clean up the save routines in xtoXXX.c
+            if (job->clean)
+                (*job->clean) ();
+        }
         // set the sensitive stuff for the control panel if we don't
         // autocontinue
         if ((orig_state & VC_CONTINUE) == 0)
             xvc_idle_add (xvc_capture_stop, job);
 
-        // clean up the save routines in xtoXXX.c
-        if (job->clean)
-            (*job->clean) ();
         // if we're recording to a movie, we must close the file now
         if (app->current_mode > 0)
             if (fp)
@@ -1354,8 +1682,8 @@ commonCapture (enum captureFunctions capfunc)
 
         if ((orig_state & VC_CONTINUE) == 0) {
             // after this we're ready to start recording again
-            xvc_job_merge_state (VC_READY);
-        } else {
+            job->state |= VC_READY;
+        } else if (job->capture_returned_errno == 0) {
 
 #ifdef DEBUG
             printf
@@ -1366,7 +1694,8 @@ commonCapture (enum captureFunctions capfunc)
             // prepare autocontinue
             job->movie_no += 1;
             job->pic_no = target->start_no;
-            xvc_job_merge_and_remove_state ((VC_START | VC_REC), VC_STOP);
+            job->state |= (VC_START | VC_REC);
+            job->state &= ~(VC_STOP);
 
             return time;
         }
@@ -1377,7 +1706,6 @@ commonCapture (enum captureFunctions capfunc)
 #endif     // DEBUG
 
     return time;
-
 #undef DEBUGFUNCTION
 }
 
