@@ -189,6 +189,15 @@ const XVC_Codec xvc_codecs[NUMCODECS] = {
      len_mpeg4_range,
      NULL,
      0},
+    {
+     "FFV1",
+     N_("FFmpeg Video 1"),
+     CODEC_ID_FFV1,
+     {24, 1},
+     one_to_hundred_range,
+     len_one_to_hundred_range,
+     NULL,
+     0},
     {
      "FLASH_VIDEO",
      N_("Flash Video"),
@@ -199,6 +208,15 @@ const XVC_Codec xvc_codecs[NUMCODECS] = {
      len_mpeg4_range,
      NULL,
      0},
+    {
+     "FLASH_SV",
+     N_("Flash Screen Video"),
+     CODEC_ID_FLASHSV,
+     {24, 1},
+     one_to_hundred_range,
+     len_one_to_hundred_range,
+     NULL,
+     0},
     {
      "DV",
      N_("DV Video"),
@@ -266,6 +284,10 @@ const XVC_AuCodec xvc_audio_codecs[NUMAUCODECS] = {
        "VORBIS",
        N_("Ogg Vorbis"),
        CODEC_ID_VORBIS}
+    , {
+       "AC3",
+       N_("Dolby Digital AC-3"),
+       CODEC_ID_AC3}
     , {
        "PCM16",
        N_("PCM"),
@@ -331,6 +353,10 @@ static const char *extension_m2v[] = { "m2v", "svcd" };
 
 #define len_extension_m2v (sizeof(extension_m2v) / sizeof(char*))
 
+static const char *extension_dvd[] = { "vob", "dvd" };
+
+#define len_extension_dvd (sizeof(extension_dvd) / sizeof(char*))
+
 static const char *extension_mov[] = { "mov", "qt" };
 
 #define len_extension_mov (sizeof(extension_mov) / sizeof(char*))
@@ -364,7 +390,8 @@ static const XVC_CodecID allowed_vid_codecs_avi[] = {
 #ifdef HAVE_LIBTHEORA
     CODEC_THEORA,
 #endif     // HAVE_LIBTHEORA
-    CODEC_DV
+    CODEC_DV,
+    CODEC_FFV1
 };
 
 #define len_allowed_vid_codecs_avi (sizeof(allowed_vid_codecs_avi) / \
@@ -375,7 +402,8 @@ static const XVC_CodecID allowed_vid_codecs_asf[] = { CODEC_MSDIV3 };
 #define len_allowed_vid_codecs_asf (sizeof(allowed_vid_codecs_asf) / \
     sizeof(XVC_CodecID))
 
-static const XVC_CodecID allowed_vid_codecs_flv[] = { CODEC_FLV };
+static const XVC_CodecID allowed_vid_codecs_flv[] =
+    { CODEC_FLV, CODEC_FLASHSV };
 
 #define len_allowed_vid_codecs_flv (sizeof(allowed_vid_codecs_flv) / \
     sizeof(XVC_CodecID))
@@ -451,6 +479,12 @@ static const XVC_AuCodecID au_codecs_mp2[] = { AU_CODEC_MP2 };
 
 #define len_au_codecs_mp2 (sizeof(au_codecs_mp2) / \
     sizeof(XVC_AuCodecID))
+
+static const XVC_AuCodecID au_codecs_ac3[] = { AU_CODEC_AC3 };
+
+#define len_au_codecs_ac3 (sizeof(au_codecs_ac3) / \
+    sizeof(XVC_AuCodecID))
+
 #endif     // HAVE_FFMPEG_AUDIO
 #endif     // USE_FFMPEG
 
@@ -660,7 +694,7 @@ const XVC_FFormat xvc_formats[NUMCAPS] = {
      len_extension_dv},
     {
      "mpeg",
-     N_("MPEG1 System Format"),
+     N_("MPEG1 System Format (VCD)"),
      "mpeg",
      CODEC_MPEG1,
      allowed_vid_codecs_mpeg1,
@@ -678,7 +712,7 @@ const XVC_FFormat xvc_formats[NUMCAPS] = {
      len_extension_m1v},
     {
      "mpeg2",
-     N_("MPEG2 PS Format"),
+     N_("MPEG2 PS Format (SVCD)"),
      "svcd",
      CODEC_MPEG2,
      allowed_vid_codecs_mpeg2,
@@ -694,6 +728,24 @@ const XVC_FFormat xvc_formats[NUMCAPS] = {
 #endif     // HAVE_FFMPEG_AUDIO
      extension_m2v,
      len_extension_m2v},
+    {
+     "vob",
+     N_("MPEG2 PS format (DVD VOB)"),
+     "dvd",
+     CODEC_MPEG2,
+     allowed_vid_codecs_mpeg2,
+     len_allowed_vid_codecs_mpeg2,
+#ifdef HAVE_FFMPEG_AUDIO
+     AU_CODEC_AC3,
+     au_codecs_ac3,
+     len_au_codecs_ac3,
+#else
+     AU_CODEC_NONE,
+     NULL,
+     0,
+#endif     // HAVE_FFMPEG_AUDIO
+     extension_dvd,
+     len_extension_dvd},
     {
      "mov",
      N_("Quicktime Format"),
@@ -918,7 +970,7 @@ xvc_get_index_of_fps_array_element (int size,
  * @return the fps value read from the string or { 0, 1}
  */
 XVC_Fps
-xvc_read_fps_from_string (char *fps_string)
+xvc_read_fps_from_string (const char *fps_string)
 {
     struct lconv *loc = localeconv ();
     XVC_Fps fps = { 0, 1 };
