@@ -22,8 +22,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ifndef __CODECS_H__
-#define __CODECS_H__
+#ifndef _xvc_CODECS_H__
+#define _xvc_CODECS_H__
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 #ifdef HAVE_CONFIG_H
@@ -38,7 +38,7 @@
  *      the AVRational struct ... and copy it because we might build without
  *      ffmpeg
  */
-typedef struct _XVC_Fps
+typedef struct _xvc_Fps
 {
     int num;
     int den;
@@ -49,7 +49,7 @@ typedef struct _XVC_Fps
  *      about those, so we wrap the XVC_Fps struct in XVC_FpsRange structs
  *      with a defined start and end
  */
-typedef struct _XVC_FpsRange
+typedef struct _xvc_FpsRange
 {
     XVC_Fps start;
     XVC_Fps end;
@@ -73,7 +73,9 @@ typedef enum
     CODEC_MPEG4,
     CODEC_MSDIV2,
     CODEC_MSDIV3,
+    CODEC_FFV1,
     CODEC_FLV,
+    CODEC_FLASHSV,
     CODEC_DV,
     CODEC_MPEG2,
 #ifdef HAVE_LIBTHEORA
@@ -92,7 +94,7 @@ typedef enum
 #endif     // USE_FFMPEG
 
 /** \brief struct containing codec properties */
-typedef struct _XVC_Codec
+typedef struct _xvc_Codec
 {
     const char *name;
     const char *longname;
@@ -120,13 +122,14 @@ typedef enum
     AU_CODEC_MP3,
 #endif     // HAVE_LIBMP3LAME
     AU_CODEC_VORBIS,
+    AU_CODEC_AC3,
     AU_CODEC_PCM16,
 #endif     // HAVE_FFMPEG_AUDIO
     NUMAUCODECS
 } XVC_AuCodecID;
 
 /** \brief struct containing audio codec properties */
-typedef struct _XVC_AuCodec
+typedef struct _xvc_AuCodec
 {
     const char *name;
     const char *longname;
@@ -157,6 +160,7 @@ typedef enum
     CAP_DV,
     CAP_MPG,
     CAP_SVCD,
+    CAP_DVD,
     CAP_MOV,
 #endif     // USE_FFMPEG
     NUMCAPS
@@ -170,7 +174,7 @@ typedef enum
 #endif     // USE_FFMPEG
 
 /** \brief struct containing file format properties */
-typedef struct _XVC_FFormat
+typedef struct _xvc_FFormat
 {
     const char *name;
     const char *longname;
@@ -222,6 +226,6 @@ int xvc_codec_is_valid_fps (XVC_Fps fps, XVC_CodecID codec, int exact);
 int xvc_get_index_of_fps_array_element (int size,
                                         const XVC_Fps * haystack,
                                         XVC_Fps needle, int exact);
-XVC_Fps xvc_read_fps_from_string (char *fps_string);
+XVC_Fps xvc_read_fps_from_string (const char *fps_string);
 
-#endif     // __CODECS_H__
+#endif     // _xvc_CODECS_H__
