@@ -25,12 +25,12 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ifndef __XVC_CONTROL_H__
-#define __XVC_CONTROL_H__
+#ifndef _xvc_XVC_CONTROL_H__
+#define _xvc_XVC_CONTROL_H__
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 #include <X11/Intrinsic.h>
-#include "xv_error_item.h"
+#include "xvc_error_item.h"
 #endif     // DOXYGEN_SHOULD_SKIP_THIS
 
 // the following defines the xvc interface for UIs
@@ -40,6 +40,8 @@
 Boolean xvc_init_pre (int argc, char **argv);
 Boolean xvc_ui_create ();
 Boolean xvc_frame_create ();
+void xvc_frame_change (int x, int y, int width, int height,
+                       Boolean reposition_control, Boolean show_dimensions);
 void xvc_check_start_options ();
 Boolean xvc_ui_init (XVC_ErrorListItem * errors);
 int xvc_ui_run (void);
@@ -55,4 +57,4 @@ Boolean xvc_frame_monitor ();
 Boolean xvc_read_options_file ();
 Boolean xvc_write_options_file ();
 
-#endif     // __XVC_CONTROL_H__
+#endif     // _xvc_XVC_CONTROL_H__
