@@ -43,11 +43,13 @@
 #include <glade/glade.h>
 #include <stdlib.h>
 #include <sys/time.h>                  // for timeval struct and related
+#include <pthread.h>
 
 #include "app_data.h"
 #include "job.h"
 #include "frame.h"
 #include "gnome_frame.h"
+#include "gnome_ui.h"
 
 #define XVC_FRAME_DIM_SHOW_TIME 2
 
@@ -69,6 +71,8 @@ static GtkWidget *gtk_frame_top,
     *gtk_frame_left, *gtk_frame_right, *gtk_frame_bottom, *gtk_frame_center;
 static GtkWidget *xvc_frame_dimensions_window;
 static gboolean button_pressed = FALSE;
+static int button_press_rel_x = 0;
+static int button_press_rel_y = 0;
 static gint frame_drag_cursor = GDK_X_CURSOR;
 static long frame_dimensions_hide_time = 0;
 static GdkDisplay *gdpy;
@@ -91,7 +95,8 @@ xvc_frame_get_capture_display ()
 #define DEBUGFUNCTION "xvc_frame_get_capure_display()"
     XVC_AppData *app = xvc_appdata_ptr ();
 
-    if (!(app->flags & FLG_NOGUI) && gtk_frame_top) {
+    if (!(app->flags & FLG_NOGUI) && !(app->flags & FLG_NOFRAME)
+        && gtk_frame_top) {
         xvc_dpy = GDK_DRAWABLE_XDISPLAY (GTK_WIDGET (gtk_frame_top)->window);
     } else {
         if (!xvc_dpy)
@@ -112,7 +117,7 @@ xvc_frame_drop_capture_display ()
 #define DEBUGFUNCTION "xvc_frame_drop_capture_display()"
     XVC_AppData *app = xvc_appdata_ptr ();
 
-    if (app->flags & FLG_NOGUI && xvc_dpy) {
+    if ((app->flags & FLG_NOGUI || app->flags & FLG_NOFRAME) && xvc_dpy) {
         gdk_display_close (gdpy);
         gdpy = NULL;
         xvc_dpy = NULL;
@@ -144,7 +149,8 @@ do_reposition_control (GtkWidget * toplevel)
     max_width = gdk_screen_get_width (GDK_SCREEN (myscreen));
     max_height = gdk_screen_get_height (GDK_SCREEN (myscreen));
 
-    gdk_window_get_frame_extents (GDK_WINDOW (toplevel->window), &rect);
+    xvc_get_ctrl_frame_extents (GDK_WINDOW (toplevel->window), &rect);
+//    gdk_window_get_frame_extents (GDK_WINDOW (toplevel->window), &rect);
     pwidth = rect.width + FRAME_OFFSET;
     pheight = rect.height + FRAME_OFFSET;
 
@@ -166,16 +172,15 @@ do_reposition_control (GtkWidget * toplevel)
 
         gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (w), FALSE);
 
-        if ((y + pheight + height + FRAME_WIDTH + FRAME_OFFSET) < max_height) {
+        if ((y + pheight + height + FRAME_WIDTH) < max_height) {
             gtk_window_move (GTK_WINDOW (toplevel), x,
                              (y + height + FRAME_OFFSET + FRAME_WIDTH));
         } else {
             if (x > pwidth + FRAME_WIDTH + FRAME_OFFSET) {
                 gtk_window_move (GTK_WINDOW (toplevel),
-                                 (x - pwidth - FRAME_OFFSET - FRAME_WIDTH), y);
+                                 (x - pwidth - FRAME_WIDTH), y);
             } else {
-                if ((x + width + pwidth + FRAME_OFFSET + FRAME_WIDTH) <
-                    max_width) {
+                if ((x + width + pwidth + FRAME_WIDTH) < max_width) {
                     gtk_window_move (GTK_WINDOW (toplevel),
                                      (x + width + FRAME_OFFSET +
                                       FRAME_WIDTH), y);
@@ -227,9 +232,7 @@ xvc_change_gtk_frame (int x, int y, int width, int height,
                       Boolean reposition_control, Boolean show_dimensions)
 {
 #define DEBUGFUNCTION "xvc_change_gtk_frame()"
-    int max_width, max_height;
     extern GtkWidget *xvc_ctrl_main_window;
-    Display *dpy;
     XRectangle *x_rect = xvc_get_capture_area ();
     XVC_AppData *app = xvc_appdata_ptr ();
     struct timeval curr_time;
@@ -267,52 +270,60 @@ xvc_change_gtk_frame (int x, int y, int width, int height,
                 printf
                     ("Modified Selection geometry: %dx%d+%d+%d\n",
                      width, height, x, y);
+                if (reposition_control)
+                    printf ("Need to reposition the maincontrol\n");
             }
         }
     }
 #endif     // USE_FFMPEG
 
     // we have to adjust it to viewable areas
-    dpy = xvc_frame_get_capture_display ();
-    max_width = WidthOfScreen (DefaultScreenOfDisplay (dpy));
-    max_height = HeightOfScreen (DefaultScreenOfDisplay (dpy));
-
 #ifdef DEBUG
     printf ("%s %s: screen = %dx%d selection=%dx%d\n", DEBUGFILE,
-            DEBUGFUNCTION, max_width, max_height, width, height);
+            DEBUGFUNCTION, app->max_width, app->max_height, width, height);
 #endif
 
     if (x < 0)
         x = 0;
-    if (width > max_width)
-        width = max_width;
-    if (x + width > max_width)
-        x = max_width - width;
+    if (width > app->max_width)
+        width = app->max_width;
+    if (x + width > app->max_width)
+        x = app->max_width - width;
 
     if (y < 0)
         y = 0;
-    if (height > max_height)
-        height = max_height;
-    if (y + height > max_height)
-        y = max_height - height;
+    if (height > app->max_height)
+        height = app->max_height;
+    if (y + height > app->max_height)
+        y = app->max_height - height;
 
-    if ((app->flags & FLG_NOGUI) == 0) {
+    if ((app->flags & FLG_NOGUI) == 0 && (app->flags & FLG_NOFRAME) == 0) {
         // move the frame if not running without GUI
-        gtk_widget_set_size_request (GTK_WIDGET (gtk_frame_top),
-                                     (width + 2 * FRAME_WIDTH), FRAME_WIDTH);
-        gtk_window_move (GTK_WINDOW (gtk_frame_top), (x - FRAME_WIDTH),
-                         (y - FRAME_WIDTH));
-        gtk_widget_set_size_request (GTK_WIDGET (gtk_frame_left),
-                                     FRAME_WIDTH, height);
-        gtk_window_move (GTK_WINDOW (gtk_frame_left), (x - FRAME_WIDTH), y);
-        gtk_widget_set_size_request (GTK_WIDGET (gtk_frame_bottom),
-                                     (width + 2 * FRAME_WIDTH), FRAME_WIDTH);
-        gtk_window_move (GTK_WINDOW (gtk_frame_bottom), (x - FRAME_WIDTH),
-                         (y + height));
-        gtk_widget_set_size_request (GTK_WIDGET (gtk_frame_right),
-                                     FRAME_WIDTH, height);
-        gtk_window_move (GTK_WINDOW (gtk_frame_right), (x + width), y);
-
+        if (width != app->area->width) {
+            gtk_widget_set_size_request (GTK_WIDGET (gtk_frame_top),
+                                         (width + 2 * FRAME_WIDTH),
+                                         FRAME_WIDTH);
+            gtk_widget_set_size_request (GTK_WIDGET (gtk_frame_bottom),
+                                         (width + 2 * FRAME_WIDTH),
+                                         FRAME_WIDTH);
+        }
+        if (height != app->area->height) {
+            gtk_widget_set_size_request (GTK_WIDGET (gtk_frame_left),
+                                         FRAME_WIDTH, height);
+            gtk_widget_set_size_request (GTK_WIDGET (gtk_frame_right),
+                                         FRAME_WIDTH, height);
+        }
+        if (x != app->area->x || y != app->area->y) {
+            gtk_window_move (GTK_WINDOW (gtk_frame_top), (x - FRAME_WIDTH),
+                             (y - FRAME_WIDTH));
+            gtk_window_move (GTK_WINDOW (gtk_frame_left), (x - FRAME_WIDTH), y);
+        }
+        if (x != app->area->x || y != app->area->y || width != app->area->width
+            || height != app->area->height) {
+            gtk_window_move (GTK_WINDOW (gtk_frame_bottom), (x - FRAME_WIDTH),
+                             (y + height));
+            gtk_window_move (GTK_WINDOW (gtk_frame_right), (x + width), y);
+        }
 #ifdef HasVideo4Linux
         // if we have a v4l blind, move it, too
         if (gtk_frame_center != NULL)
@@ -333,7 +344,7 @@ xvc_change_gtk_frame (int x, int y, int width, int height,
     if (((app->flags & FLG_NOGUI) == 0) && reposition_control)
         do_reposition_control (xvc_ctrl_main_window);
 
-    if (show_dimensions) {
+    if (show_dimensions && ((app->flags & FLG_NOFRAME) == 0)) {
         xml = glade_get_widget_tree (GTK_WIDGET (xvc_frame_dimensions_window));
         g_assert (xml);
         w = glade_xml_get_widget (xml, "xvc_frame_size_label");
@@ -372,16 +383,30 @@ on_gtk_frame_configure_event (GtkWidget * w, GdkEventConfigure * e)
 #define DEBUGFUNCTION "on_gtk_frame_configure_event()"
     gint x, y, pwidth, pheight;
     XVC_AppData *app = xvc_appdata_ptr ();
+    Job *job = xvc_job_ptr ();
 
-    if (xvc_is_frame_locked ()) {
-        x = ((GdkEventConfigure *) e)->x;
-        y = ((GdkEventConfigure *) e)->y;
-        pwidth = ((GdkEventConfigure *) e)->width;
-        pheight = ((GdkEventConfigure *) e)->height;
+    if ((app->flags & FLG_LOCK_FOLLOWS_MOUSE) == 0 && xvc_is_frame_locked ()) {
+        GdkRectangle rect;
 
+        xvc_get_ctrl_frame_extents (GDK_WINDOW (w->window), &rect);
+//        gdk_window_get_frame_extents (GDK_WINDOW (w->window), &rect);
+
+        x = rect.x;
+        y = rect.y;
+        pwidth = rect.width;
+        pheight = rect.height;
         y += pheight + FRAME_OFFSET + FRAME_WIDTH;
-        xvc_change_gtk_frame (x, y, app->area->width, app->area->height,
-                              FALSE, FALSE);
+
+        // don't move the frame in the middle of capturing
+        // let the capture thread take care of that
+        if (!app->recording_thread_running) {
+            xvc_change_gtk_frame (x, y, app->area->width, app->area->height,
+                                  FALSE, FALSE);
+        } else {
+            // tell the capture job we moved the frame
+            job->frame_moved_x = x - app->area->x;
+            job->frame_moved_y = y - app->area->y;
+        }
     }
     return FALSE;
 #undef DEBUGFUNCTION
@@ -492,7 +517,7 @@ on_gtk_frame_leave_notify_event (GtkWidget * w, GdkEventCrossing * event)
 gint
 on_gtk_frame_motion_notify_event (GtkWidget * w, GdkEventMotion * event)
 {
-    gint x, y, x_root, y_root;
+    gint x, y, x_root, y_root, twidth, theight;
     GdkCursor *cursor;
     XVC_AppData *app = xvc_appdata_ptr ();
     Job *job = xvc_job_ptr ();
@@ -505,6 +530,9 @@ on_gtk_frame_motion_notify_event (GtkWidget * w, GdkEventMotion * event)
     x_root = (int) event->x_root;
     y_root = (int) event->y_root;
 
+//    printf("xr: %i - off: %i --- x: %i -- width: %i\n", x_root, button_press_rel_x, app->area->x, app->area->width);
+//    printf("yr: %i - off: %i --- y: %i\n", y_root, button_press_rel_y, app->area->y);
+
     if (!button_pressed) {
         if (w == gtk_frame_right) {
             if (y < XVC_MIN (FRAME_EDGE_SIZE, w->allocation.height / 3)) {
@@ -567,78 +595,139 @@ on_gtk_frame_motion_notify_event (GtkWidget * w, GdkEventMotion * event)
         }
     } else {
         if (frame_drag_cursor == GDK_TOP_RIGHT_CORNER) {
+            x_root = x_root - button_press_rel_x;
+            y_root = y_root + button_press_rel_y;
+
             if (x_root < (app->area->x + 20))
                 x_root = app->area->x + 20;
             if (y_root > (app->area->y + app->area->height - 20))
                 y_root = app->area->y + app->area->height - 20;
+            twidth = x_root - app->area->x;
+            if ((twidth % 2) > 0) {
+                twidth--;
+                x_root--;
+            }
+            theight = app->area->height - y_root + app->area->y;
+            if ((theight % 2) > 0) {
+                theight--;
+                y_root++;
+            }
 
             xvc_change_gtk_frame (app->area->x, y_root,
-                                  abs (x_root - app->area->x),
-                                  abs (y_root -
-                                       (app->area->y + app->area->height)),
-                                  FALSE, TRUE);
+                                  twidth, theight, FALSE, TRUE);
         } else if (frame_drag_cursor == GDK_BOTTOM_RIGHT_CORNER) {
+            x_root = x_root - button_press_rel_x;
+            y_root = y_root - button_press_rel_y;
+
             if (x_root < (app->area->x + 20))
                 x_root = app->area->x + 20;
             if (y_root < (app->area->y + 20))
                 y_root = app->area->y + 20;
+            twidth = x_root - app->area->x;
+            if ((twidth % 2) > 0) {
+                twidth--;
+                x_root--;
+            }
+            theight = y_root - app->area->y;
+            if ((theight % 2) > 0) {
+                theight--;
+                y_root--;
+            }
 
             xvc_change_gtk_frame (app->area->x, app->area->y,
-                                  abs (x_root - app->area->x),
-                                  abs (y_root - app->area->y), FALSE, TRUE);
+                                  twidth, theight, FALSE, TRUE);
         } else if (frame_drag_cursor == GDK_RIGHT_SIDE) {
+            x_root = x_root - button_press_rel_x;
+
             if (x_root < (app->area->x + 20))
                 x_root = app->area->x + 20;
+            twidth = x_root - app->area->x;
+            if ((twidth % 2) > 0) {
+                twidth--;
+                x_root--;
+            }
 
             xvc_change_gtk_frame (app->area->x, app->area->y,
-                                  abs (x_root - app->area->x),
-                                  app->area->height, FALSE, TRUE);
+                                  twidth, app->area->height, FALSE, TRUE);
         } else if (frame_drag_cursor == GDK_TOP_SIDE) {
+            y_root = y_root + button_press_rel_y;
+
             if (y_root > (app->area->y + app->area->height - 20))
                 y_root = app->area->y + app->area->height - 20;
+            theight = app->area->height - y_root + app->area->y;
+            if ((theight % 2) > 0) {
+                theight--;
+                y_root++;
+            }
 
             xvc_change_gtk_frame (app->area->x, y_root,
-                                  app->area->width,
-                                  abs (y_root -
-                                       (app->area->y + app->area->height)),
-                                  FALSE, TRUE);
+                                  app->area->width, theight, FALSE, TRUE);
         } else if (frame_drag_cursor == GDK_TOP_LEFT_CORNER) {
+            x_root = x_root + button_press_rel_x;
+            y_root = y_root + button_press_rel_y;
+
             if (x_root > (app->area->x + app->area->width - 20))
                 x_root = app->area->x + app->area->width - 20;
             if (y_root > (app->area->y + app->area->height - 20))
                 y_root = app->area->y + app->area->height - 20;
+            twidth = app->area->width - x_root + app->area->x;
+            if ((twidth % 2) > 0) {
+                twidth--;
+                x_root++;
+            }
+            theight = app->area->height - y_root + app->area->y;
+            if ((theight % 2) > 0) {
+                theight--;
+                y_root++;
+            }
 
-            xvc_change_gtk_frame (x_root, y_root,
-                                  abs (x_root -
-                                       (app->area->x + app->area->width)),
-                                  abs (y_root -
-                                       (app->area->y + app->area->height)),
-                                  FALSE, TRUE);
+            xvc_change_gtk_frame (x_root, y_root, twidth, theight, FALSE, TRUE);
         } else if (frame_drag_cursor == GDK_LEFT_SIDE) {
+            x_root = x_root + button_press_rel_x;
             if (x_root > (app->area->x + app->area->width - 20))
                 x_root = app->area->x + app->area->width - 20;
+            twidth = app->area->width - (x_root - app->area->x);
+            if ((twidth % 2) > 0) {
+                x_root++;
+                twidth--;
+            }
 
             xvc_change_gtk_frame (x_root, app->area->y,
-                                  abs (x_root -
-                                       (app->area->x + app->area->width)),
-                                  app->area->height, FALSE, TRUE);
+                                  twidth, app->area->height, FALSE, TRUE);
         } else if (frame_drag_cursor == GDK_BOTTOM_LEFT_CORNER) {
+            x_root = x_root + button_press_rel_x;
+            y_root = y_root - button_press_rel_y;
+
             if (x_root > (app->area->x + app->area->width - 20))
                 x_root = app->area->x + app->area->width - 20;
             if (y_root < (app->area->y + 20))
                 y_root = app->area->y + 20;
+            twidth = app->area->width - x_root + app->area->x;
+            if ((twidth % 2) > 0) {
+                twidth--;
+                x_root++;
+            }
+            theight = y_root - app->area->y;
+            if ((theight % 2) > 0) {
+                theight--;
+                y_root--;
+            }
 
             xvc_change_gtk_frame (x_root, app->area->y,
-                                  abs (x_root -
-                                       (app->area->x + app->area->width)),
-                                  abs (y_root - app->area->y), FALSE, TRUE);
+                                  twidth, theight, FALSE, TRUE);
         } else {                       // GDK_BOTTOM_SIDE
+            y_root = y_root - button_press_rel_y;
+
             if (y_root < (app->area->y + 20))
                 y_root = app->area->y + 20;
+            theight = y_root - app->area->y;
+            if ((theight % 2) > 0) {
+                theight--;
+                y_root--;
+            }
 
             xvc_change_gtk_frame (app->area->x, app->area->y,
-                                  app->area->width,
-                                  abs (y_root - app->area->y), FALSE, TRUE);
+                                  app->area->width, theight, FALSE, TRUE);
         }
     }
     return 0;
@@ -650,7 +739,35 @@ on_gtk_frame_motion_notify_event (GtkWidget * w, GdkEventMotion * event)
 gint
 on_gtk_frame_button_press_event (GtkWidget * w, GdkEventButton * event)
 {
+    XVC_AppData *app = xvc_appdata_ptr ();
+
     button_pressed = TRUE;
+    if (w == gtk_frame_right) {
+        button_press_rel_x = event->x + 1;
+        button_press_rel_y = 0;
+    } else if (w == gtk_frame_top) {
+        if (event->x < FRAME_WIDTH) {
+            button_press_rel_x = FRAME_WIDTH - event->x - 1;
+        } else if (event->x > app->area->width + FRAME_WIDTH) {
+            button_press_rel_x = event->x - app->area->width - FRAME_WIDTH;
+        } else {
+            button_press_rel_x = 0;
+        }
+        button_press_rel_y = FRAME_WIDTH - event->y - 1;
+    } else if (w == gtk_frame_bottom) {
+        if (event->x < FRAME_WIDTH) {
+            button_press_rel_x = FRAME_WIDTH - event->x - 1;
+        } else if (event->x > app->area->width + FRAME_WIDTH) {
+            button_press_rel_x = event->x - app->area->width - FRAME_WIDTH;
+        } else {
+            button_press_rel_x = 0;
+        }
+        button_press_rel_y = event->y + 1;
+    } else {
+        button_press_rel_x = FRAME_WIDTH - event->x - 1;
+        button_press_rel_y = 0;
+    }
+//    printf("x %i y %i\n", button_press_rel_x, button_press_rel_y);
     return 0;
 }
 
@@ -692,8 +809,6 @@ xvc_create_gtk_frame (GtkWidget * toplevel, int pwidth, int pheight,
     int flags = app->flags;
     XRectangle *x_rect = xvc_get_capture_area ();
     GladeXML *xml = NULL;
-    int max_width, max_height;
-    Display *dpy;
 
 #ifdef DEBUG
     printf ("%s %s: x %d y %d width %d height %d\n", DEBUGFILE,
@@ -735,28 +850,27 @@ xvc_create_gtk_frame (GtkWidget * toplevel, int pwidth, int pheight,
 #endif     // USE_FFMPEG
 
     // we have to adjust it to viewable areas
-    dpy = xvc_frame_get_capture_display ();
-    max_width = WidthOfScreen (DefaultScreenOfDisplay (dpy));
-    max_height = HeightOfScreen (DefaultScreenOfDisplay (dpy));
+//    max_width = WidthOfScreen (DefaultScreenOfDisplay (app->dpy));
+//    max_height = HeightOfScreen (DefaultScreenOfDisplay (app->dpy));
 
 #ifdef DEBUG
     printf ("%s %s: screen = %dx%d selection=%dx%d\n", DEBUGFILE,
-            DEBUGFUNCTION, max_width, max_height, pwidth, pheight);
+            DEBUGFUNCTION, app->max_width, app->max_height, pwidth, pheight);
 #endif
 
     if (x < 0)
         x = 0;
-    if (pwidth > max_width)
-        pwidth = max_width;
-    if (x + pwidth > max_width)
-        x = max_width - pwidth;
+    if (pwidth > app->max_width)
+        pwidth = app->max_width;
+    if (x + pwidth > app->max_width)
+        x = app->max_width - pwidth;
 
     if (y < 0)
         y = 0;
-    if (pheight > max_height)
-        pheight = max_height;
-    if (y + pheight > max_height)
-        y = max_height - pheight;
+    if (pheight > app->max_height)
+        pheight = app->max_height;
+    if (y + pheight > app->max_height)
+        y = app->max_height - pheight;
 
     // now for the real work
     if (!(flags & FLG_NOGUI)) {
@@ -764,11 +878,13 @@ xvc_create_gtk_frame (GtkWidget * toplevel, int pwidth, int pheight,
 
         if (px < 0 && py < 0) {
             // compute position for frame
-            gdk_window_get_origin (GDK_WINDOW (toplevel->window), &x, &y);
-            gdk_window_get_frame_extents (GDK_WINDOW (toplevel->window), &rect);
+            xvc_get_ctrl_frame_extents (GDK_WINDOW (toplevel->window), &rect);
+//            gdk_window_get_frame_extents (GDK_WINDOW (toplevel->window), &rect);
 
             if (x < 0)
                 x = 0;
+
+            y = rect.y;
             y += rect.height + FRAME_OFFSET;
             if (y < 0)
                 y = 0;
@@ -790,7 +906,7 @@ xvc_create_gtk_frame (GtkWidget * toplevel, int pwidth, int pheight,
     x_rect->y = y;
 
     // create frame
-    if (!(flags & FLG_NOGUI)) {
+    if (!(flags & FLG_NOGUI) && !(flags & FLG_NOFRAME)) {
 
         // top of frame
         gtk_frame_top = gtk_window_new (GTK_WINDOW_POPUP);
@@ -1024,12 +1140,6 @@ xvc_create_gtk_frame (GtkWidget * toplevel, int pwidth, int pheight,
             // XtPopup(blind, XtGrabNone);
         }
 #endif     // HasVideo4Linux
-        // connect event-handler to configure event of gtk control window
-        // to redraw the selection frame if the control is moved and the
-        // frame is locked
-        g_signal_connect (G_OBJECT (toplevel), "configure-event",
-                          G_CALLBACK (on_gtk_frame_configure_event), NULL);
-
         g_signal_connect (G_OBJECT (gtk_frame_top), "enter_notify_event",
                           G_CALLBACK (on_gtk_frame_enter_notify_event), NULL);
         g_signal_connect (G_OBJECT (gtk_frame_left), "enter_notify_event",
@@ -1076,6 +1186,15 @@ xvc_create_gtk_frame (GtkWidget * toplevel, int pwidth, int pheight,
                           G_CALLBACK (on_gtk_frame_button_release_event), NULL);
 
     }
+    // connect event-handler to configure event of gtk control window
+    // to redraw the selection frame if the control is moved and the
+    // frame is locked
+    // this is also required with FLG_NOFRAME
+    if (!(flags & FLG_NOGUI)) {
+        g_signal_connect (G_OBJECT (toplevel), "configure-event",
+                          G_CALLBACK (on_gtk_frame_configure_event), NULL);
+    }
+
     xvc_set_frame_locked (1);
 
     if (!(flags & FLG_NOGUI) && (px >= 0 || py >= 0))
@@ -1092,13 +1211,29 @@ xvc_destroy_gtk_frame ()
 {
 #define DEBUGFUNCTION "xvc_destroy_gtk_frame()"
 
-    gtk_widget_destroy (gtk_frame_bottom);
-    gtk_widget_destroy (gtk_frame_right);
-    gtk_widget_destroy (gtk_frame_left);
-    gtk_widget_destroy (gtk_frame_top);
-    gtk_widget_destroy (xvc_frame_dimensions_window);
+    if (gtk_frame_bottom) {
+        gtk_widget_destroy (gtk_frame_bottom);
+        gtk_frame_bottom = NULL;
+    }
+    if (gtk_frame_right) {
+        gtk_widget_destroy (gtk_frame_right);
+        gtk_frame_right = NULL;
+    }
+    if (gtk_frame_left) {
+        gtk_widget_destroy (gtk_frame_left);
+        gtk_frame_left = NULL;
+    }
+    if (gtk_frame_top) {
+        gtk_widget_destroy (gtk_frame_top);
+        gtk_frame_top = NULL;
+    }
+    if (xvc_frame_dimensions_window) {
+        gtk_widget_destroy (xvc_frame_dimensions_window);
+        xvc_frame_dimensions_window = NULL;
+    }
     if (gtk_frame_center) {
         gtk_widget_destroy (gtk_frame_center);
+        gtk_frame_center = NULL;
     }
 #undef DEBUGFUNCTION
 }
