@@ -211,6 +211,28 @@ read_app_data_from_pref_gui (XVC_AppData * lapp)
         lapp->mouseWanted = 0;
     }
 
+    // capture area follows mouse pointer
+    w = NULL;
+    w = glade_xml_get_widget (xml, "xvc_pref_follow_mouse_checkbutton");
+    g_assert (w);
+
+    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w))) {
+        lapp->flags |= FLG_LOCK_FOLLOWS_MOUSE;
+    } else {
+        lapp->flags &= ~FLG_LOCK_FOLLOWS_MOUSE;
+    }
+
+    // hide frame around capture area
+    w = NULL;
+    w = glade_xml_get_widget (xml, "xvc_pref_hide_frame_checkbutton");
+    g_assert (w);
+
+    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w))) {
+        lapp->flags |= FLG_NOFRAME;
+    } else {
+        lapp->flags &= ~FLG_NOFRAME;
+    }
+
     // save geometry
     w = NULL;
     w = glade_xml_get_widget (xml, "xvc_pref_save_geometry_checkbutton");
@@ -478,8 +500,9 @@ read_app_data_from_pref_gui (XVC_AppData * lapp)
             exit (1);
         }
 #ifdef DEBUG
-        printf ("%s %s: read fps: %i\n", DEBUGFILE, DEBUGFUNCTION,
-                lapp->multi_frame.fps);
+        printf ("%s %s: read fps: %f\n", DEBUGFILE, DEBUGFUNCTION,
+                ((float) lapp->multi_frame.fps.num /
+                 (float) lapp->multi_frame.fps.den));
 #endif     // DEBUG
     }
 
@@ -1119,6 +1142,26 @@ xvc_create_pref_dialog (XVC_AppData * lapp)
             gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), FALSE);
         }
     }
+    // capture area follows mouse pointer
+    w = NULL;
+    w = glade_xml_get_widget (xml, "xvc_pref_follow_mouse_checkbutton");
+    if (w != NULL) {
+        if ((pref_app.flags & FLG_LOCK_FOLLOWS_MOUSE) != 0) {
+            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), TRUE);
+        } else {
+            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), FALSE);
+        }
+    }
+    // hide frame around capture area
+    w = NULL;
+    w = glade_xml_get_widget (xml, "xvc_pref_hide_frame_checkbutton");
+    if (w != NULL) {
+        if ((pref_app.flags & FLG_NOFRAME) != 0) {
+            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), TRUE);
+        } else {
+            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), FALSE);
+        }
+    }
     // shared memory
     w = NULL;
     w = glade_xml_get_widget (xml, "xvc_pref_shared_mem_checkbutton");
@@ -2081,7 +2124,7 @@ on_xvc_pref_mf_format_combobox_changed (GtkComboBox * combobox,
     g_assert (w);
     if (w != GTK_WIDGET (combobox)) {
 #ifdef DEBUG
-        printf ("%s %s: change combobox %p %p %i\n", DEBUGFILE, DEBUGFUNCTION,
+        printf ("%s %s: change combobox %p %p\n", DEBUGFILE, DEBUGFUNCTION,
                 w, combobox);
 #endif     // DEBUG
         combobox = GTK_COMBO_BOX (w);
@@ -2835,7 +2878,7 @@ on_xvc_pref_sf_filename_select_button_clicked (GtkButton * button,
 {
 #define DEBUGFUNCTION "on_xvc_pref_sf_filename_select_button_clicked()"
     int result = 0;
-    char *got_file_name;
+    char *got_file_name = NULL;
 
     GladeXML *xml = NULL;
     GtkWidget *w = NULL, *dialog = NULL;
@@ -2886,7 +2929,7 @@ on_xvc_pref_mf_filename_select_button_clicked (GtkButton * button,
 {
 #define DEBUGFUNCTION "on_xvc_pref_mf_filename_select_button_clicked()"
     int result = 0;
-    char *got_file_name;
+    char *got_file_name = NULL;
 
     GladeXML *xml = NULL;
     GtkWidget *w = NULL, *dialog = NULL;
@@ -2937,7 +2980,7 @@ on_xvc_pref_mf_audio_input_device_select_button_clicked (GtkButton * button,
 {
 #define DEBUGFUNCTION "on_xvc_pref_mf_audio_input_device_select_button_clicked()"
     int result = 0;
-    char *got_file_name;
+    char *got_file_name = NULL;
 
     GladeXML *xml = NULL;
     GtkWidget *w = NULL, *dialog = NULL;
