@@ -20,481 +20,483 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ifndef __XVC_GNOME_UI_H__
-#define __XVC_GNOME_UI_H__
+#ifndef _xvc_XVC_GNOME_UI_H__
+#define _xvc_XVC_GNOME_UI_H__
 
 #include <glib.h>
+#include <gdk/gdkx.h>
 
 static const gchar xvc_logo_small[] = {
     0x2f, 0x2a, 0x20, 0x58, 0x50, 0x4d, 0x20, 0x2a, 0x2f, 0x0a, 0x73, 0x74,
-        0x61, 0x74, 0x69, 0x63,
+    0x61, 0x74, 0x69, 0x63,
     0x20, 0x63, 0x68, 0x61, 0x72, 0x20, 0x2a, 0x20, 0x78, 0x76, 0x69, 0x64,
-        0x63, 0x61, 0x70, 0x5f,
+    0x63, 0x61, 0x70, 0x5f,
     0x6c, 0x6f, 0x67, 0x6f, 0x5f, 0x6b, 0x6c, 0x65, 0x69, 0x6e, 0x5f, 0x78,
-        0x70, 0x6d, 0x5b, 0x5d,
+    0x70, 0x6d, 0x5b, 0x5d,
     0x20, 0x3d, 0x20, 0x7b, 0x0a, 0x22, 0x32, 0x30, 0x20, 0x32, 0x30, 0x20,
-        0x31, 0x37, 0x33, 0x20,
+    0x31, 0x37, 0x33, 0x20,
     0x32, 0x22, 0x2c, 0x0a, 0x22, 0x20, 0x20, 0x09, 0x63, 0x20, 0x4e, 0x6f,
-        0x6e, 0x65, 0x22, 0x2c,
+    0x6e, 0x65, 0x22, 0x2c,
     0x0a, 0x22, 0x2e, 0x20, 0x09, 0x63, 0x20, 0x23, 0x39, 0x37, 0x39, 0x37,
-        0x39, 0x37, 0x22, 0x2c,
+    0x39, 0x37, 0x22, 0x2c,
     0x0a, 0x22, 0x2b, 0x20, 0x09, 0x63, 0x20, 0x23, 0x31, 0x34, 0x31, 0x34,
-        0x31, 0x34, 0x22, 0x2c,
+    0x31, 0x34, 0x22, 0x2c,
     0x0a, 0x22, 0x40, 0x20, 0x09, 0x63, 0x20, 0x23, 0x30, 0x36, 0x30, 0x36,
-        0x30, 0x36, 0x22, 0x2c,
+    0x30, 0x36, 0x22, 0x2c,
     0x0a, 0x22, 0x23, 0x20, 0x09, 0x63, 0x20, 0x23, 0x30, 0x35, 0x30, 0x35,
-        0x30, 0x35, 0x22, 0x2c,
+    0x30, 0x35, 0x22, 0x2c,
     0x0a, 0x22, 0x24, 0x20, 0x09, 0x63, 0x20, 0x23, 0x31, 0x37, 0x31, 0x37,
-        0x31, 0x37, 0x22, 0x2c,
+    0x31, 0x37, 0x22, 0x2c,
     0x0a, 0x22, 0x25, 0x20, 0x09, 0x63, 0x20, 0x23, 0x37, 0x46, 0x37, 0x46,
-        0x37, 0x46, 0x22, 0x2c,
+    0x37, 0x46, 0x22, 0x2c,
     0x0a, 0x22, 0x26, 0x20, 0x09, 0x63, 0x20, 0x23, 0x37, 0x32, 0x37, 0x32,
-        0x37, 0x32, 0x22, 0x2c,
+    0x37, 0x32, 0x22, 0x2c,
     0x0a, 0x22, 0x2a, 0x20, 0x09, 0x63, 0x20, 0x23, 0x34, 0x39, 0x34, 0x39,
-        0x34, 0x39, 0x22, 0x2c,
+    0x34, 0x39, 0x22, 0x2c,
     0x0a, 0x22, 0x3d, 0x20, 0x09, 0x63, 0x20, 0x23, 0x41, 0x31, 0x41, 0x31,
-        0x41, 0x31, 0x22, 0x2c,
+    0x41, 0x31, 0x22, 0x2c,
     0x0a, 0x22, 0x2d, 0x20, 0x09, 0x63, 0x20, 0x23, 0x32, 0x34, 0x32, 0x34,
-        0x32, 0x34, 0x22, 0x2c,
+    0x32, 0x34, 0x22, 0x2c,
     0x0a, 0x22, 0x3b, 0x20, 0x09, 0x63, 0x20, 0x23, 0x42, 0x36, 0x42, 0x36,
-        0x42, 0x36, 0x22, 0x2c,
+    0x42, 0x36, 0x22, 0x2c,
     0x0a, 0x22, 0x3e, 0x20, 0x09, 0x63, 0x20, 0x23, 0x30, 0x46, 0x30, 0x46,
-        0x30, 0x46, 0x22, 0x2c,
+    0x30, 0x46, 0x22, 0x2c,
     0x0a, 0x22, 0x2c, 0x20, 0x09, 0x63, 0x20, 0x23, 0x32, 0x37, 0x32, 0x37,
-        0x32, 0x37, 0x22, 0x2c,
+    0x32, 0x37, 0x22, 0x2c,
     0x0a, 0x22, 0x27, 0x20, 0x09, 0x63, 0x20, 0x23, 0x30, 0x30, 0x30, 0x30,
-        0x30, 0x30, 0x22, 0x2c,
+    0x30, 0x30, 0x22, 0x2c,
     0x0a, 0x22, 0x29, 0x20, 0x09, 0x63, 0x20, 0x23, 0x30, 0x34, 0x30, 0x34,
-        0x30, 0x34, 0x22, 0x2c,
+    0x30, 0x34, 0x22, 0x2c,
     0x0a, 0x22, 0x21, 0x20, 0x09, 0x63, 0x20, 0x23, 0x33, 0x35, 0x33, 0x35,
-        0x33, 0x35, 0x22, 0x2c,
+    0x33, 0x35, 0x22, 0x2c,
     0x0a, 0x22, 0x7e, 0x20, 0x09, 0x63, 0x20, 0x23, 0x34, 0x33, 0x34, 0x33,
-        0x34, 0x33, 0x22, 0x2c,
+    0x34, 0x33, 0x22, 0x2c,
     0x0a, 0x22, 0x7b, 0x20, 0x09, 0x63, 0x20, 0x23, 0x31, 0x44, 0x31, 0x44,
-        0x31, 0x44, 0x22, 0x2c,
+    0x31, 0x44, 0x22, 0x2c,
     0x0a, 0x22, 0x5d, 0x20, 0x09, 0x63, 0x20, 0x23, 0x41, 0x34, 0x41, 0x34,
-        0x41, 0x34, 0x22, 0x2c,
+    0x41, 0x34, 0x22, 0x2c,
     0x0a, 0x22, 0x5e, 0x20, 0x09, 0x63, 0x20, 0x23, 0x31, 0x30, 0x31, 0x30,
-        0x31, 0x30, 0x22, 0x2c,
+    0x31, 0x30, 0x22, 0x2c,
     0x0a, 0x22, 0x2f, 0x20, 0x09, 0x63, 0x20, 0x23, 0x30, 0x31, 0x30, 0x31,
-        0x30, 0x31, 0x22, 0x2c,
+    0x30, 0x31, 0x22, 0x2c,
     0x0a, 0x22, 0x28, 0x20, 0x09, 0x63, 0x20, 0x23, 0x30, 0x38, 0x30, 0x38,
-        0x30, 0x38, 0x22, 0x2c,
+    0x30, 0x38, 0x22, 0x2c,
     0x0a, 0x22, 0x5f, 0x20, 0x09, 0x63, 0x20, 0x23, 0x36, 0x42, 0x36, 0x42,
-        0x36, 0x42, 0x22, 0x2c,
+    0x36, 0x42, 0x22, 0x2c,
     0x0a, 0x22, 0x3a, 0x20, 0x09, 0x63, 0x20, 0x23, 0x34, 0x42, 0x34, 0x42,
-        0x34, 0x42, 0x22, 0x2c,
+    0x34, 0x42, 0x22, 0x2c,
     0x0a, 0x22, 0x3c, 0x20, 0x09, 0x63, 0x20, 0x23, 0x39, 0x43, 0x39, 0x43,
-        0x39, 0x43, 0x22, 0x2c,
+    0x39, 0x43, 0x22, 0x2c,
     0x0a, 0x22, 0x5b, 0x20, 0x09, 0x63, 0x20, 0x23, 0x42, 0x31, 0x42, 0x31,
-        0x42, 0x31, 0x22, 0x2c,
+    0x42, 0x31, 0x22, 0x2c,
     0x0a, 0x22, 0x7d, 0x20, 0x09, 0x63, 0x20, 0x23, 0x32, 0x32, 0x32, 0x32,
-        0x32, 0x32, 0x22, 0x2c,
+    0x32, 0x32, 0x22, 0x2c,
     0x0a, 0x22, 0x7c, 0x20, 0x09, 0x63, 0x20, 0x23, 0x34, 0x44, 0x34, 0x44,
-        0x34, 0x44, 0x22, 0x2c,
+    0x34, 0x44, 0x22, 0x2c,
     0x0a, 0x22, 0x31, 0x20, 0x09, 0x63, 0x20, 0x23, 0x30, 0x39, 0x30, 0x39,
-        0x30, 0x39, 0x22, 0x2c,
+    0x30, 0x39, 0x22, 0x2c,
     0x0a, 0x22, 0x32, 0x20, 0x09, 0x63, 0x20, 0x23, 0x36, 0x46, 0x36, 0x46,
-        0x36, 0x46, 0x22, 0x2c,
+    0x36, 0x46, 0x22, 0x2c,
     0x0a, 0x22, 0x33, 0x20, 0x09, 0x63, 0x20, 0x23, 0x32, 0x39, 0x32, 0x39,
-        0x32, 0x39, 0x22, 0x2c,
+    0x32, 0x39, 0x22, 0x2c,
     0x0a, 0x22, 0x34, 0x20, 0x09, 0x63, 0x20, 0x23, 0x30, 0x45, 0x30, 0x45,
-        0x30, 0x45, 0x22, 0x2c,
+    0x30, 0x45, 0x22, 0x2c,
     0x0a, 0x22, 0x35, 0x20, 0x09, 0x63, 0x20, 0x23, 0x32, 0x31, 0x32, 0x31,
-        0x32, 0x31, 0x22, 0x2c,
+    0x32, 0x31, 0x22, 0x2c,
     0x0a, 0x22, 0x36, 0x20, 0x09, 0x63, 0x20, 0x23, 0x38, 0x38, 0x38, 0x38,
-        0x38, 0x38, 0x22, 0x2c,
+    0x38, 0x38, 0x22, 0x2c,
     0x0a, 0x22, 0x37, 0x20, 0x09, 0x63, 0x20, 0x23, 0x36, 0x32, 0x36, 0x32,
-        0x36, 0x32, 0x22, 0x2c,
+    0x36, 0x32, 0x22, 0x2c,
     0x0a, 0x22, 0x38, 0x20, 0x09, 0x63, 0x20, 0x23, 0x38, 0x46, 0x38, 0x46,
-        0x38, 0x46, 0x22, 0x2c,
+    0x38, 0x46, 0x22, 0x2c,
     0x0a, 0x22, 0x39, 0x20, 0x09, 0x63, 0x20, 0x23, 0x36, 0x38, 0x36, 0x38,
-        0x36, 0x38, 0x22, 0x2c,
+    0x36, 0x38, 0x22, 0x2c,
     0x0a, 0x22, 0x30, 0x20, 0x09, 0x63, 0x20, 0x23, 0x38, 0x31, 0x38, 0x31,
-        0x38, 0x31, 0x22, 0x2c,
+    0x38, 0x31, 0x22, 0x2c,
     0x0a, 0x22, 0x61, 0x20, 0x09, 0x63, 0x20, 0x23, 0x34, 0x46, 0x34, 0x46,
-        0x34, 0x46, 0x22, 0x2c,
+    0x34, 0x46, 0x22, 0x2c,
     0x0a, 0x22, 0x62, 0x20, 0x09, 0x63, 0x20, 0x23, 0x30, 0x41, 0x30, 0x41,
-        0x30, 0x41, 0x22, 0x2c,
+    0x30, 0x41, 0x22, 0x2c,
     0x0a, 0x22, 0x63, 0x20, 0x09, 0x63, 0x20, 0x23, 0x33, 0x36, 0x33, 0x36,
-        0x33, 0x36, 0x22, 0x2c,
+    0x33, 0x36, 0x22, 0x2c,
     0x0a, 0x22, 0x64, 0x20, 0x09, 0x63, 0x20, 0x23, 0x36, 0x41, 0x36, 0x41,
-        0x36, 0x41, 0x22, 0x2c,
+    0x36, 0x41, 0x22, 0x2c,
     0x0a, 0x22, 0x65, 0x20, 0x09, 0x63, 0x20, 0x23, 0x36, 0x44, 0x36, 0x44,
-        0x36, 0x44, 0x22, 0x2c,
+    0x36, 0x44, 0x22, 0x2c,
     0x0a, 0x22, 0x66, 0x20, 0x09, 0x63, 0x20, 0x23, 0x41, 0x32, 0x41, 0x32,
-        0x41, 0x32, 0x22, 0x2c,
+    0x41, 0x32, 0x22, 0x2c,
     0x0a, 0x22, 0x67, 0x20, 0x09, 0x63, 0x20, 0x23, 0x43, 0x45, 0x43, 0x45,
-        0x43, 0x45, 0x22, 0x2c,
+    0x43, 0x45, 0x22, 0x2c,
     0x0a, 0x22, 0x68, 0x20, 0x09, 0x63, 0x20, 0x23, 0x43, 0x39, 0x43, 0x39,
-        0x43, 0x39, 0x22, 0x2c,
+    0x43, 0x39, 0x22, 0x2c,
     0x0a, 0x22, 0x69, 0x20, 0x09, 0x63, 0x20, 0x23, 0x31, 0x38, 0x31, 0x38,
-        0x31, 0x38, 0x22, 0x2c,
+    0x31, 0x38, 0x22, 0x2c,
     0x0a, 0x22, 0x6a, 0x20, 0x09, 0x63, 0x20, 0x23, 0x34, 0x35, 0x34, 0x35,
-        0x34, 0x35, 0x22, 0x2c,
+    0x34, 0x35, 0x22, 0x2c,
     0x0a, 0x22, 0x6b, 0x20, 0x09, 0x63, 0x20, 0x23, 0x35, 0x42, 0x35, 0x42,
-        0x35, 0x42, 0x22, 0x2c,
+    0x35, 0x42, 0x22, 0x2c,
     0x0a, 0x22, 0x6c, 0x20, 0x09, 0x63, 0x20, 0x23, 0x37, 0x46, 0x37, 0x45,
-        0x37, 0x45, 0x22, 0x2c,
+    0x37, 0x45, 0x22, 0x2c,
     0x0a, 0x22, 0x6d, 0x20, 0x09, 0x63, 0x20, 0x23, 0x39, 0x46, 0x39, 0x46,
-        0x39, 0x46, 0x22, 0x2c,
+    0x39, 0x46, 0x22, 0x2c,
     0x0a, 0x22, 0x6e, 0x20, 0x09, 0x63, 0x20, 0x23, 0x30, 0x33, 0x30, 0x33,
-        0x30, 0x33, 0x22, 0x2c,
+    0x30, 0x33, 0x22, 0x2c,
     0x0a, 0x22, 0x6f, 0x20, 0x09, 0x63, 0x20, 0x23, 0x34, 0x31, 0x32, 0x42,
-        0x32, 0x45, 0x22, 0x2c,
+    0x32, 0x45, 0x22, 0x2c,
     0x0a, 0x22, 0x70, 0x20, 0x09, 0x63, 0x20, 0x23, 0x34, 0x39, 0x32, 0x30,
-        0x32, 0x35, 0x22, 0x2c,
+    0x32, 0x35, 0x22, 0x2c,
     0x0a, 0x22, 0x71, 0x20, 0x09, 0x63, 0x20, 0x23, 0x34, 0x33, 0x32, 0x31,
-        0x32, 0x36, 0x22, 0x2c,
+    0x32, 0x36, 0x22, 0x2c,
     0x0a, 0x22, 0x72, 0x20, 0x09, 0x63, 0x20, 0x23, 0x31, 0x39, 0x31, 0x37,
-        0x31, 0x38, 0x22, 0x2c,
+    0x31, 0x38, 0x22, 0x2c,
     0x0a, 0x22, 0x73, 0x20, 0x09, 0x63, 0x20, 0x23, 0x31, 0x39, 0x30, 0x43,
-        0x30, 0x45, 0x22, 0x2c,
+    0x30, 0x45, 0x22, 0x2c,
     0x0a, 0x22, 0x74, 0x20, 0x09, 0x63, 0x20, 0x23, 0x32, 0x46, 0x31, 0x34,
-        0x31, 0x37, 0x22, 0x2c,
+    0x31, 0x37, 0x22, 0x2c,
     0x0a, 0x22, 0x75, 0x20, 0x09, 0x63, 0x20, 0x23, 0x33, 0x33, 0x31, 0x35,
-        0x31, 0x39, 0x22, 0x2c,
+    0x31, 0x39, 0x22, 0x2c,
     0x0a, 0x22, 0x76, 0x20, 0x09, 0x63, 0x20, 0x23, 0x34, 0x34, 0x31, 0x43,
-        0x32, 0x30, 0x22, 0x2c,
+    0x32, 0x30, 0x22, 0x2c,
     0x0a, 0x22, 0x77, 0x20, 0x09, 0x63, 0x20, 0x23, 0x33, 0x46, 0x31, 0x45,
-        0x32, 0x32, 0x22, 0x2c,
+    0x32, 0x32, 0x22, 0x2c,
     0x0a, 0x22, 0x78, 0x20, 0x09, 0x63, 0x20, 0x23, 0x31, 0x42, 0x31, 0x42,
-        0x31, 0x42, 0x22, 0x2c,
+    0x31, 0x42, 0x22, 0x2c,
     0x0a, 0x22, 0x79, 0x20, 0x09, 0x63, 0x20, 0x23, 0x31, 0x35, 0x31, 0x35,
-        0x31, 0x35, 0x22, 0x2c,
+    0x31, 0x35, 0x22, 0x2c,
     0x0a, 0x22, 0x7a, 0x20, 0x09, 0x63, 0x20, 0x23, 0x32, 0x31, 0x30, 0x43,
-        0x30, 0x45, 0x22, 0x2c,
+    0x30, 0x45, 0x22, 0x2c,
     0x0a, 0x22, 0x41, 0x20, 0x09, 0x63, 0x20, 0x23, 0x38, 0x39, 0x30, 0x37,
-        0x31, 0x32, 0x22, 0x2c,
+    0x31, 0x32, 0x22, 0x2c,
     0x0a, 0x22, 0x42, 0x20, 0x09, 0x63, 0x20, 0x23, 0x34, 0x34, 0x30, 0x41,
-        0x31, 0x30, 0x22, 0x2c,
+    0x31, 0x30, 0x22, 0x2c,
     0x0a, 0x22, 0x43, 0x20, 0x09, 0x63, 0x20, 0x23, 0x31, 0x34, 0x30, 0x39,
-        0x30, 0x41, 0x22, 0x2c,
+    0x30, 0x41, 0x22, 0x2c,
     0x0a, 0x22, 0x44, 0x20, 0x09, 0x63, 0x20, 0x23, 0x34, 0x38, 0x30, 0x34,
-        0x30, 0x43, 0x22, 0x2c,
+    0x30, 0x43, 0x22, 0x2c,
     0x0a, 0x22, 0x45, 0x20, 0x09, 0x63, 0x20, 0x23, 0x36, 0x35, 0x30, 0x30,
-        0x30, 0x38, 0x22, 0x2c,
+    0x30, 0x38, 0x22, 0x2c,
     0x0a, 0x22, 0x46, 0x20, 0x09, 0x63, 0x20, 0x23, 0x36, 0x45, 0x30, 0x30,
-        0x30, 0x44, 0x22, 0x2c,
+    0x30, 0x44, 0x22, 0x2c,
     0x0a, 0x22, 0x47, 0x20, 0x09, 0x63, 0x20, 0x23, 0x39, 0x30, 0x30, 0x30,
-        0x30, 0x43, 0x22, 0x2c,
+    0x30, 0x43, 0x22, 0x2c,
     0x0a, 0x22, 0x48, 0x20, 0x09, 0x63, 0x20, 0x23, 0x37, 0x31, 0x30, 0x30,
-        0x30, 0x42, 0x22, 0x2c,
+    0x30, 0x42, 0x22, 0x2c,
     0x0a, 0x22, 0x49, 0x20, 0x09, 0x63, 0x20, 0x23, 0x42, 0x38, 0x42, 0x38,
-        0x42, 0x37, 0x22, 0x2c,
+    0x42, 0x37, 0x22, 0x2c,
     0x0a, 0x22, 0x4a, 0x20, 0x09, 0x63, 0x20, 0x23, 0x35, 0x44, 0x35, 0x44,
-        0x35, 0x44, 0x22, 0x2c,
+    0x35, 0x44, 0x22, 0x2c,
     0x0a, 0x22, 0x4b, 0x20, 0x09, 0x63, 0x20, 0x23, 0x33, 0x36, 0x33, 0x31,
-        0x33, 0x32, 0x22, 0x2c,
+    0x33, 0x32, 0x22, 0x2c,
     0x0a, 0x22, 0x4c, 0x20, 0x09, 0x63, 0x20, 0x23, 0x30, 0x42, 0x30, 0x42,
-        0x30, 0x42, 0x22, 0x2c,
+    0x30, 0x42, 0x22, 0x2c,
     0x0a, 0x22, 0x4d, 0x20, 0x09, 0x63, 0x20, 0x23, 0x33, 0x31, 0x33, 0x30,
-        0x33, 0x30, 0x22, 0x2c,
+    0x33, 0x30, 0x22, 0x2c,
     0x0a, 0x22, 0x4e, 0x20, 0x09, 0x63, 0x20, 0x23, 0x32, 0x42, 0x32, 0x36,
-        0x32, 0x37, 0x22, 0x2c,
+    0x32, 0x37, 0x22, 0x2c,
     0x0a, 0x22, 0x4f, 0x20, 0x09, 0x63, 0x20, 0x23, 0x33, 0x36, 0x33, 0x30,
-        0x33, 0x31, 0x22, 0x2c,
+    0x33, 0x31, 0x22, 0x2c,
     0x0a, 0x22, 0x50, 0x20, 0x09, 0x63, 0x20, 0x23, 0x33, 0x46, 0x33, 0x37,
-        0x33, 0x39, 0x22, 0x2c,
+    0x33, 0x39, 0x22, 0x2c,
     0x0a, 0x22, 0x51, 0x20, 0x09, 0x63, 0x20, 0x23, 0x34, 0x31, 0x33, 0x39,
-        0x33, 0x41, 0x22, 0x2c,
+    0x33, 0x41, 0x22, 0x2c,
     0x0a, 0x22, 0x52, 0x20, 0x09, 0x63, 0x20, 0x23, 0x32, 0x36, 0x31, 0x46,
-        0x32, 0x30, 0x22, 0x2c,
+    0x32, 0x30, 0x22, 0x2c,
     0x0a, 0x22, 0x53, 0x20, 0x09, 0x63, 0x20, 0x23, 0x34, 0x39, 0x34, 0x38,
-        0x34, 0x37, 0x22, 0x2c,
+    0x34, 0x37, 0x22, 0x2c,
     0x0a, 0x22, 0x54, 0x20, 0x09, 0x63, 0x20, 0x23, 0x38, 0x30, 0x37, 0x46,
-        0x37, 0x44, 0x22, 0x2c,
+    0x37, 0x44, 0x22, 0x2c,
     0x0a, 0x22, 0x55, 0x20, 0x09, 0x63, 0x20, 0x23, 0x42, 0x31, 0x42, 0x31,
-        0x42, 0x30, 0x22, 0x2c,
+    0x42, 0x30, 0x22, 0x2c,
     0x0a, 0x22, 0x56, 0x20, 0x09, 0x63, 0x20, 0x23, 0x37, 0x38, 0x37, 0x38,
-        0x37, 0x38, 0x22, 0x2c,
+    0x37, 0x38, 0x22, 0x2c,
     0x0a, 0x22, 0x57, 0x20, 0x09, 0x63, 0x20, 0x23, 0x34, 0x41, 0x34, 0x41,
-        0x34, 0x41, 0x22, 0x2c,
+    0x34, 0x41, 0x22, 0x2c,
     0x0a, 0x22, 0x58, 0x20, 0x09, 0x63, 0x20, 0x23, 0x30, 0x37, 0x30, 0x37,
-        0x30, 0x37, 0x22, 0x2c,
+    0x30, 0x37, 0x22, 0x2c,
     0x0a, 0x22, 0x59, 0x20, 0x09, 0x63, 0x20, 0x23, 0x32, 0x43, 0x32, 0x43,
-        0x32, 0x43, 0x22, 0x2c,
+    0x32, 0x43, 0x22, 0x2c,
     0x0a, 0x22, 0x5a, 0x20, 0x09, 0x63, 0x20, 0x23, 0x32, 0x44, 0x32, 0x44,
-        0x32, 0x44, 0x22, 0x2c,
+    0x32, 0x44, 0x22, 0x2c,
     0x0a, 0x22, 0x60, 0x20, 0x09, 0x63, 0x20, 0x23, 0x33, 0x32, 0x33, 0x32,
-        0x33, 0x32, 0x22, 0x2c,
+    0x33, 0x32, 0x22, 0x2c,
     0x0a, 0x22, 0x20, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x32, 0x30, 0x32, 0x30,
-        0x32, 0x30, 0x22, 0x2c,
+    0x32, 0x30, 0x22, 0x2c,
     0x0a, 0x22, 0x2e, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x33, 0x35, 0x33, 0x36,
-        0x33, 0x38, 0x22, 0x2c,
+    0x33, 0x38, 0x22, 0x2c,
     0x0a, 0x22, 0x2b, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x35, 0x46, 0x36, 0x38,
-        0x37, 0x32, 0x22, 0x2c,
+    0x37, 0x32, 0x22, 0x2c,
     0x0a, 0x22, 0x40, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x42, 0x43, 0x42, 0x42,
-        0x42, 0x38, 0x22, 0x2c,
+    0x42, 0x38, 0x22, 0x2c,
     0x0a, 0x22, 0x23, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x41, 0x38, 0x41, 0x38,
-        0x41, 0x38, 0x22, 0x2c,
+    0x41, 0x38, 0x22, 0x2c,
     0x0a, 0x22, 0x24, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x37, 0x39, 0x37, 0x41,
-        0x37, 0x39, 0x22, 0x2c,
+    0x37, 0x39, 0x22, 0x2c,
     0x0a, 0x22, 0x25, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x36, 0x45, 0x37, 0x30,
-        0x37, 0x34, 0x22, 0x2c,
+    0x37, 0x34, 0x22, 0x2c,
     0x0a, 0x22, 0x26, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x33, 0x39, 0x33, 0x39,
-        0x33, 0x42, 0x22, 0x2c,
+    0x33, 0x42, 0x22, 0x2c,
     0x0a, 0x22, 0x2a, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x31, 0x32, 0x31, 0x32,
-        0x31, 0x32, 0x22, 0x2c,
+    0x31, 0x32, 0x22, 0x2c,
     0x0a, 0x22, 0x3d, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x33, 0x33, 0x33, 0x33,
-        0x33, 0x33, 0x22, 0x2c,
+    0x33, 0x33, 0x22, 0x2c,
     0x0a, 0x22, 0x2d, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x33, 0x45, 0x33, 0x45,
-        0x33, 0x45, 0x22, 0x2c,
+    0x33, 0x45, 0x22, 0x2c,
     0x0a, 0x22, 0x3b, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x34, 0x37, 0x34, 0x37,
-        0x34, 0x37, 0x22, 0x2c,
+    0x34, 0x37, 0x22, 0x2c,
     0x0a, 0x22, 0x3e, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x34, 0x36, 0x34, 0x36,
-        0x34, 0x36, 0x22, 0x2c,
+    0x34, 0x36, 0x22, 0x2c,
     0x0a, 0x22, 0x2c, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x31, 0x44, 0x31, 0x45,
-        0x32, 0x30, 0x22, 0x2c,
+    0x32, 0x30, 0x22, 0x2c,
     0x0a, 0x22, 0x27, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x32, 0x44, 0x33, 0x35,
-        0x33, 0x45, 0x22, 0x2c,
+    0x33, 0x45, 0x22, 0x2c,
     0x0a, 0x22, 0x29, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x41, 0x34, 0x41, 0x33,
-        0x41, 0x32, 0x22, 0x2c,
+    0x41, 0x32, 0x22, 0x2c,
     0x0a, 0x22, 0x21, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x38, 0x37, 0x38, 0x37,
-        0x38, 0x37, 0x22, 0x2c,
+    0x38, 0x37, 0x22, 0x2c,
     0x0a, 0x22, 0x7e, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x37, 0x31, 0x37, 0x42,
-        0x38, 0x45, 0x22, 0x2c,
+    0x38, 0x45, 0x22, 0x2c,
     0x0a, 0x22, 0x7b, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x34, 0x36, 0x34, 0x37,
-        0x34, 0x39, 0x22, 0x2c,
+    0x34, 0x39, 0x22, 0x2c,
     0x0a, 0x22, 0x5d, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x33, 0x38, 0x33, 0x38,
-        0x33, 0x38, 0x22, 0x2c,
+    0x33, 0x38, 0x22, 0x2c,
     0x0a, 0x22, 0x5e, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x33, 0x37, 0x33, 0x37,
-        0x33, 0x37, 0x22, 0x2c,
+    0x33, 0x37, 0x22, 0x2c,
     0x0a, 0x22, 0x2f, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x33, 0x42, 0x33, 0x42,
-        0x33, 0x42, 0x22, 0x2c,
+    0x33, 0x42, 0x22, 0x2c,
     0x0a, 0x22, 0x28, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x33, 0x39, 0x33, 0x39,
-        0x33, 0x39, 0x22, 0x2c,
+    0x33, 0x39, 0x22, 0x2c,
     0x0a, 0x22, 0x5f, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x36, 0x35, 0x36, 0x35,
-        0x36, 0x34, 0x22, 0x2c,
+    0x36, 0x34, 0x22, 0x2c,
     0x0a, 0x22, 0x3a, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x38, 0x44, 0x38, 0x44,
-        0x38, 0x43, 0x22, 0x2c,
+    0x38, 0x43, 0x22, 0x2c,
     0x0a, 0x22, 0x3c, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x44, 0x31, 0x44, 0x30,
-        0x43, 0x46, 0x22, 0x2c,
+    0x43, 0x46, 0x22, 0x2c,
     0x0a, 0x22, 0x5b, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x42, 0x46, 0x42, 0x46,
-        0x42, 0x45, 0x22, 0x2c,
+    0x42, 0x45, 0x22, 0x2c,
     0x0a, 0x22, 0x7d, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x38, 0x36, 0x38, 0x37,
-        0x38, 0x36, 0x22, 0x2c,
+    0x38, 0x36, 0x22, 0x2c,
     0x0a, 0x22, 0x7c, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x32, 0x43, 0x33, 0x42,
-        0x35, 0x42, 0x22, 0x2c,
+    0x35, 0x42, 0x22, 0x2c,
     0x0a, 0x22, 0x31, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x30, 0x39, 0x30, 0x41,
-        0x30, 0x44, 0x22, 0x2c,
+    0x30, 0x44, 0x22, 0x2c,
     0x0a, 0x22, 0x32, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x32, 0x36, 0x32, 0x41,
-        0x32, 0x46, 0x22, 0x2c,
+    0x32, 0x46, 0x22, 0x2c,
     0x0a, 0x22, 0x33, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x31, 0x45, 0x32, 0x31,
-        0x32, 0x34, 0x22, 0x2c,
+    0x32, 0x34, 0x22, 0x2c,
     0x0a, 0x22, 0x34, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x30, 0x44, 0x30, 0x44,
-        0x30, 0x44, 0x22, 0x2c,
+    0x30, 0x44, 0x22, 0x2c,
     0x0a, 0x22, 0x35, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x37, 0x32, 0x37, 0x32,
-        0x37, 0x33, 0x22, 0x2c,
+    0x37, 0x33, 0x22, 0x2c,
     0x0a, 0x22, 0x36, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x37, 0x37, 0x37, 0x37,
-        0x37, 0x37, 0x22, 0x2c,
+    0x37, 0x37, 0x22, 0x2c,
     0x0a, 0x22, 0x37, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x37, 0x36, 0x37, 0x36,
-        0x37, 0x36, 0x22, 0x2c,
+    0x37, 0x36, 0x22, 0x2c,
     0x0a, 0x22, 0x38, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x36, 0x30, 0x36, 0x32,
-        0x36, 0x36, 0x22, 0x2c,
+    0x36, 0x36, 0x22, 0x2c,
     0x0a, 0x22, 0x39, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x35, 0x35, 0x35, 0x38,
-        0x35, 0x45, 0x22, 0x2c,
+    0x35, 0x45, 0x22, 0x2c,
     0x0a, 0x22, 0x30, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x41, 0x33, 0x41, 0x34,
-        0x41, 0x36, 0x22, 0x2c,
+    0x41, 0x36, 0x22, 0x2c,
     0x0a, 0x22, 0x61, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x37, 0x33, 0x37, 0x33,
-        0x37, 0x33, 0x22, 0x2c,
+    0x37, 0x33, 0x22, 0x2c,
     0x0a, 0x22, 0x62, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x31, 0x32, 0x31, 0x34,
-        0x31, 0x36, 0x22, 0x2c,
+    0x31, 0x36, 0x22, 0x2c,
     0x0a, 0x22, 0x63, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x30, 0x44, 0x31, 0x41,
-        0x32, 0x43, 0x22, 0x2c,
+    0x32, 0x43, 0x22, 0x2c,
     0x0a, 0x22, 0x64, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x31, 0x35, 0x32, 0x38,
-        0x34, 0x30, 0x22, 0x2c,
+    0x34, 0x30, 0x22, 0x2c,
     0x0a, 0x22, 0x65, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x32, 0x37, 0x33, 0x32,
-        0x33, 0x38, 0x22, 0x2c,
+    0x33, 0x38, 0x22, 0x2c,
     0x0a, 0x22, 0x66, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x31, 0x44, 0x32, 0x30,
-        0x32, 0x32, 0x22, 0x2c,
+    0x32, 0x32, 0x22, 0x2c,
     0x0a, 0x22, 0x67, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x41, 0x39, 0x41, 0x39,
-        0x41, 0x39, 0x22, 0x2c,
+    0x41, 0x39, 0x22, 0x2c,
     0x0a, 0x22, 0x68, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x42, 0x37, 0x42, 0x37,
-        0x42, 0x37, 0x22, 0x2c,
+    0x42, 0x37, 0x22, 0x2c,
     0x0a, 0x22, 0x69, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x37, 0x34, 0x37, 0x41,
-        0x38, 0x33, 0x22, 0x2c,
+    0x38, 0x33, 0x22, 0x2c,
     0x0a, 0x22, 0x6a, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x41, 0x43, 0x41, 0x43,
-        0x41, 0x43, 0x22, 0x2c,
+    0x41, 0x43, 0x22, 0x2c,
     0x0a, 0x22, 0x6b, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x32, 0x42, 0x32, 0x42,
-        0x32, 0x42, 0x22, 0x2c,
+    0x32, 0x42, 0x22, 0x2c,
     0x0a, 0x22, 0x6c, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x31, 0x43, 0x31, 0x44,
-        0x32, 0x30, 0x22, 0x2c,
+    0x32, 0x30, 0x22, 0x2c,
     0x0a, 0x22, 0x6d, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x33, 0x30, 0x33, 0x43,
-        0x35, 0x32, 0x22, 0x2c,
+    0x35, 0x32, 0x22, 0x2c,
     0x0a, 0x22, 0x6e, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x33, 0x34, 0x34, 0x35,
-        0x35, 0x43, 0x22, 0x2c,
+    0x35, 0x43, 0x22, 0x2c,
     0x0a, 0x22, 0x6f, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x34, 0x33, 0x34, 0x46,
-        0x35, 0x41, 0x22, 0x2c,
+    0x35, 0x41, 0x22, 0x2c,
     0x0a, 0x22, 0x70, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x32, 0x45, 0x33, 0x33,
-        0x33, 0x36, 0x22, 0x2c,
+    0x33, 0x36, 0x22, 0x2c,
     0x0a, 0x22, 0x71, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x41, 0x44, 0x41, 0x46,
-        0x42, 0x31, 0x22, 0x2c,
+    0x42, 0x31, 0x22, 0x2c,
     0x0a, 0x22, 0x72, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x34, 0x42, 0x35, 0x34,
-        0x35, 0x46, 0x22, 0x2c,
+    0x35, 0x46, 0x22, 0x2c,
     0x0a, 0x22, 0x73, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x36, 0x32, 0x36, 0x33,
-        0x36, 0x33, 0x22, 0x2c,
+    0x36, 0x33, 0x22, 0x2c,
     0x0a, 0x22, 0x74, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x37, 0x30, 0x37, 0x30,
-        0x37, 0x30, 0x22, 0x2c,
+    0x37, 0x30, 0x22, 0x2c,
     0x0a, 0x22, 0x75, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x38, 0x35, 0x38, 0x35,
-        0x38, 0x35, 0x22, 0x2c,
+    0x38, 0x35, 0x22, 0x2c,
     0x0a, 0x22, 0x76, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x39, 0x44, 0x39, 0x44,
-        0x39, 0x44, 0x22, 0x2c,
+    0x39, 0x44, 0x22, 0x2c,
     0x0a, 0x22, 0x77, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x30, 0x32, 0x30, 0x32,
-        0x30, 0x32, 0x22, 0x2c,
+    0x30, 0x32, 0x22, 0x2c,
     0x0a, 0x22, 0x78, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x39, 0x43, 0x39, 0x46,
-        0x41, 0x34, 0x22, 0x2c,
+    0x41, 0x34, 0x22, 0x2c,
     0x0a, 0x22, 0x79, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x34, 0x35, 0x34, 0x42,
-        0x35, 0x32, 0x22, 0x2c,
+    0x35, 0x32, 0x22, 0x2c,
     0x0a, 0x22, 0x7a, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x34, 0x43, 0x34, 0x43,
-        0x34, 0x42, 0x22, 0x2c,
+    0x34, 0x42, 0x22, 0x2c,
     0x0a, 0x22, 0x41, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x38, 0x33, 0x38, 0x33,
-        0x38, 0x33, 0x22, 0x2c,
+    0x38, 0x33, 0x22, 0x2c,
     0x0a, 0x22, 0x42, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x39, 0x41, 0x39, 0x41,
-        0x39, 0x39, 0x22, 0x2c,
+    0x39, 0x39, 0x22, 0x2c,
     0x0a, 0x22, 0x43, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x39, 0x31, 0x39, 0x34,
-        0x39, 0x36, 0x22, 0x2c,
+    0x39, 0x36, 0x22, 0x2c,
     0x0a, 0x22, 0x44, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x31, 0x33, 0x31, 0x34,
-        0x31, 0x35, 0x22, 0x2c,
+    0x31, 0x35, 0x22, 0x2c,
     0x0a, 0x22, 0x45, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x36, 0x31, 0x36, 0x31,
-        0x36, 0x30, 0x22, 0x2c,
+    0x36, 0x30, 0x22, 0x2c,
     0x0a, 0x22, 0x46, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x38, 0x30, 0x38, 0x30,
-        0x38, 0x30, 0x22, 0x2c,
+    0x38, 0x30, 0x22, 0x2c,
     0x0a, 0x22, 0x47, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x39, 0x31, 0x39, 0x31,
-        0x39, 0x31, 0x22, 0x2c,
+    0x39, 0x31, 0x22, 0x2c,
     0x0a, 0x22, 0x48, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x39, 0x30, 0x39, 0x30,
-        0x39, 0x30, 0x22, 0x2c,
+    0x39, 0x30, 0x22, 0x2c,
     0x0a, 0x22, 0x49, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x34, 0x44, 0x34, 0x44,
-        0x34, 0x45, 0x22, 0x2c,
+    0x34, 0x45, 0x22, 0x2c,
     0x0a, 0x22, 0x4a, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x31, 0x41, 0x31, 0x42,
-        0x31, 0x45, 0x22, 0x2c,
+    0x31, 0x45, 0x22, 0x2c,
     0x0a, 0x22, 0x4b, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x37, 0x44, 0x37, 0x44,
-        0x37, 0x44, 0x22, 0x2c,
+    0x37, 0x44, 0x22, 0x2c,
     0x0a, 0x22, 0x4c, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x37, 0x41, 0x37, 0x41,
-        0x37, 0x41, 0x22, 0x2c,
+    0x37, 0x41, 0x22, 0x2c,
     0x0a, 0x22, 0x4d, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x31, 0x41, 0x31, 0x41,
-        0x31, 0x41, 0x22, 0x2c,
+    0x31, 0x41, 0x22, 0x2c,
     0x0a, 0x22, 0x4e, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x34, 0x31, 0x34, 0x33,
-        0x34, 0x35, 0x22, 0x2c,
+    0x34, 0x35, 0x22, 0x2c,
     0x0a, 0x22, 0x4f, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x32, 0x30, 0x32, 0x34,
-        0x32, 0x38, 0x22, 0x2c,
+    0x32, 0x38, 0x22, 0x2c,
     0x0a, 0x22, 0x50, 0x2e, 0x09, 0x63, 0x20, 0x23, 0x36, 0x31, 0x36, 0x31,
-        0x36, 0x31, 0x22, 0x2c,
+    0x36, 0x31, 0x22, 0x2c,
     0x0a, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
-        0x20, 0x20, 0x20, 0x20,
+    0x20, 0x20, 0x20, 0x20,
     0x20, 0x20, 0x20, 0x20, 0x2e, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
-        0x20, 0x20, 0x20, 0x20,
+    0x20, 0x20, 0x20, 0x20,
     0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x2c,
-        0x0a, 0x22, 0x20, 0x20,
+    0x0a, 0x22, 0x20, 0x20,
     0x20, 0x20, 0x20, 0x20, 0x2b, 0x20, 0x40, 0x20, 0x23, 0x20, 0x40, 0x20,
-        0x24, 0x20, 0x20, 0x20,
+    0x24, 0x20, 0x20, 0x20,
     0x20, 0x20, 0x25, 0x20, 0x26, 0x20, 0x2a, 0x20, 0x3d, 0x20, 0x2d, 0x20,
-        0x3b, 0x20, 0x20, 0x20,
+    0x3b, 0x20, 0x20, 0x20,
     0x20, 0x20, 0x3e, 0x20, 0x2c, 0x20, 0x22, 0x2c, 0x0a, 0x22, 0x20, 0x20,
-        0x20, 0x20, 0x20, 0x20,
+    0x20, 0x20, 0x20, 0x20,
     0x20, 0x20, 0x23, 0x20, 0x27, 0x20, 0x27, 0x20, 0x29, 0x20, 0x20, 0x20,
-        0x20, 0x20, 0x20, 0x20,
+    0x20, 0x20, 0x20, 0x20,
     0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x21, 0x20,
-        0x7e, 0x20, 0x7b, 0x20,
+    0x7e, 0x20, 0x7b, 0x20,
     0x5d, 0x20, 0x22, 0x2c, 0x0a, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
-        0x20, 0x20, 0x5e, 0x20,
+    0x20, 0x20, 0x5e, 0x20,
     0x2f, 0x20, 0x27, 0x20, 0x27, 0x20, 0x28, 0x20, 0x5f, 0x20, 0x25, 0x20,
-        0x3a, 0x20, 0x3c, 0x20,
+    0x3a, 0x20, 0x3c, 0x20,
     0x21, 0x20, 0x5b, 0x20, 0x7d, 0x20, 0x7c, 0x20, 0x31, 0x20, 0x32, 0x20,
-        0x33, 0x20, 0x22, 0x2c,
+    0x33, 0x20, 0x22, 0x2c,
     0x0a, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x2f, 0x20,
-        0x34, 0x20, 0x27, 0x20,
+    0x34, 0x20, 0x27, 0x20,
     0x27, 0x20, 0x27, 0x20, 0x35, 0x20, 0x36, 0x20, 0x37, 0x20, 0x38, 0x20,
-        0x39, 0x20, 0x30, 0x20,
+    0x39, 0x20, 0x30, 0x20,
     0x61, 0x20, 0x62, 0x20, 0x63, 0x20, 0x61, 0x20, 0x64, 0x20, 0x22, 0x2c,
-        0x0a, 0x22, 0x20, 0x20,
+    0x0a, 0x22, 0x20, 0x20,
     0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x2f, 0x20, 0x31, 0x20, 0x31, 0x20,
-        0x27, 0x20, 0x27, 0x20,
+    0x27, 0x20, 0x27, 0x20,
     0x27, 0x20, 0x65, 0x20, 0x66, 0x20, 0x67, 0x20, 0x68, 0x20, 0x2e, 0x20,
-        0x69, 0x20, 0x6a, 0x20,
+    0x69, 0x20, 0x6a, 0x20,
     0x6b, 0x20, 0x6c, 0x20, 0x6d, 0x20, 0x22, 0x2c, 0x0a, 0x22, 0x20, 0x20,
-        0x20, 0x20, 0x20, 0x20,
+    0x20, 0x20, 0x20, 0x20,
     0x20, 0x20, 0x20, 0x20, 0x27, 0x20, 0x62, 0x20, 0x6e, 0x20, 0x27, 0x20,
-        0x27, 0x20, 0x28, 0x20,
+    0x27, 0x20, 0x28, 0x20,
     0x6f, 0x20, 0x70, 0x20, 0x71, 0x20, 0x72, 0x20, 0x73, 0x20, 0x74, 0x20,
-        0x75, 0x20, 0x76, 0x20,
+    0x75, 0x20, 0x76, 0x20,
     0x77, 0x20, 0x22, 0x2c, 0x0a, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
-        0x20, 0x20, 0x20, 0x20,
+    0x20, 0x20, 0x20, 0x20,
     0x29, 0x20, 0x78, 0x20, 0x79, 0x20, 0x2f, 0x20, 0x27, 0x20, 0x27, 0x20,
-        0x7a, 0x20, 0x41, 0x20,
+    0x7a, 0x20, 0x41, 0x20,
     0x42, 0x20, 0x43, 0x20, 0x44, 0x20, 0x45, 0x20, 0x46, 0x20, 0x47, 0x20,
-        0x48, 0x20, 0x22, 0x2c,
+    0x48, 0x20, 0x22, 0x2c,
     0x0a, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x49, 0x20,
-        0x2e, 0x20, 0x4a, 0x20,
+    0x2e, 0x20, 0x4a, 0x20,
     0x2c, 0x20, 0x34, 0x20, 0x27, 0x20, 0x27, 0x20, 0x23, 0x20, 0x4b, 0x20,
-        0x4c, 0x20, 0x4d, 0x20,
+    0x4c, 0x20, 0x4d, 0x20,
     0x4e, 0x20, 0x4f, 0x20, 0x50, 0x20, 0x51, 0x20, 0x52, 0x20, 0x22, 0x2c,
-        0x0a, 0x22, 0x20, 0x20,
+    0x0a, 0x22, 0x20, 0x20,
     0x20, 0x20, 0x53, 0x20, 0x54, 0x20, 0x49, 0x20, 0x55, 0x20, 0x56, 0x20,
-        0x57, 0x20, 0x7d, 0x20,
+    0x57, 0x20, 0x7d, 0x20,
     0x58, 0x20, 0x27, 0x20, 0x2d, 0x20, 0x34, 0x20, 0x69, 0x20, 0x7b, 0x20,
-        0x59, 0x20, 0x5a, 0x20,
+    0x59, 0x20, 0x5a, 0x20,
     0x63, 0x20, 0x60, 0x20, 0x20, 0x2e, 0x22, 0x2c, 0x0a, 0x22, 0x20, 0x20,
-        0x20, 0x20, 0x2e, 0x2e,
+    0x20, 0x20, 0x2e, 0x2e,
     0x2b, 0x2e, 0x40, 0x2e, 0x23, 0x2e, 0x24, 0x2e, 0x25, 0x2e, 0x26, 0x2e,
-        0x2a, 0x2e, 0x2a, 0x2e,
+    0x2a, 0x2e, 0x2a, 0x2e,
     0x2a, 0x2e, 0x27, 0x20, 0x58, 0x20, 0x3d, 0x2e, 0x2d, 0x2e, 0x3b, 0x2e,
-        0x3e, 0x2e, 0x2a, 0x20,
+    0x3e, 0x2e, 0x2a, 0x20,
     0x20, 0x2e, 0x22, 0x2c, 0x0a, 0x22, 0x20, 0x20, 0x20, 0x20, 0x2c, 0x2e,
-        0x27, 0x2e, 0x29, 0x2e,
+    0x27, 0x2e, 0x29, 0x2e,
     0x49, 0x20, 0x21, 0x2e, 0x7e, 0x2e, 0x7b, 0x2e, 0x62, 0x20, 0x7b, 0x20,
-        0x27, 0x20, 0x27, 0x20,
+    0x27, 0x20, 0x27, 0x20,
     0x27, 0x20, 0x79, 0x20, 0x5d, 0x2e, 0x5e, 0x2e, 0x5d, 0x2e, 0x2f, 0x2e,
-        0x28, 0x2e, 0x22, 0x2c,
+    0x28, 0x2e, 0x22, 0x2c,
     0x0a, 0x22, 0x20, 0x20, 0x20, 0x20, 0x5f, 0x2e, 0x3a, 0x2e, 0x3c, 0x2e,
-        0x5b, 0x2e, 0x7d, 0x2e,
+    0x5b, 0x2e, 0x7d, 0x2e,
     0x7c, 0x2e, 0x31, 0x2e, 0x32, 0x2e, 0x33, 0x2e, 0x34, 0x2e, 0x27, 0x20,
-        0x27, 0x20, 0x27, 0x20,
+    0x27, 0x20, 0x27, 0x20,
     0x2f, 0x2e, 0x35, 0x2e, 0x36, 0x2e, 0x37, 0x2e, 0x36, 0x2e, 0x22, 0x2c,
-        0x0a, 0x22, 0x20, 0x20,
+    0x0a, 0x22, 0x20, 0x20,
     0x20, 0x20, 0x38, 0x2e, 0x39, 0x2e, 0x30, 0x2e, 0x5b, 0x2e, 0x61, 0x2e,
-        0x62, 0x2e, 0x63, 0x2e,
+    0x62, 0x2e, 0x63, 0x2e,
     0x64, 0x2e, 0x65, 0x2e, 0x66, 0x2e, 0x23, 0x20, 0x27, 0x20, 0x27, 0x20,
-        0x58, 0x20, 0x20, 0x20,
+    0x58, 0x20, 0x20, 0x20,
     0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x22, 0x2c, 0x0a, 0x22, 0x20, 0x20,
-        0x20, 0x20, 0x67, 0x2e,
+    0x20, 0x20, 0x67, 0x2e,
     0x68, 0x2e, 0x69, 0x2e, 0x6a, 0x2e, 0x6b, 0x2e, 0x6c, 0x2e, 0x6d, 0x2e,
-        0x6e, 0x2e, 0x6f, 0x2e,
+    0x6e, 0x2e, 0x6f, 0x2e,
     0x70, 0x2e, 0x34, 0x2e, 0x2f, 0x20, 0x27, 0x20, 0x27, 0x20, 0x28, 0x20,
-        0x20, 0x20, 0x20, 0x20,
+    0x20, 0x20, 0x20, 0x20,
     0x20, 0x20, 0x22, 0x2c, 0x0a, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
-        0x71, 0x2e, 0x72, 0x2e,
+    0x71, 0x2e, 0x72, 0x2e,
     0x73, 0x2e, 0x2a, 0x2e, 0x74, 0x2e, 0x75, 0x2e, 0x76, 0x2e, 0x20, 0x20,
-        0x77, 0x2e, 0x77, 0x2e,
+    0x77, 0x2e, 0x77, 0x2e,
     0x62, 0x20, 0x27, 0x20, 0x27, 0x20, 0x27, 0x20, 0x2a, 0x2e, 0x20, 0x20,
-        0x20, 0x20, 0x22, 0x2c,
+    0x20, 0x20, 0x22, 0x2c,
     0x0a, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x78, 0x2e, 0x79, 0x2e,
-        0x28, 0x20, 0x7a, 0x2e,
+    0x28, 0x20, 0x7a, 0x2e,
     0x32, 0x20, 0x41, 0x2e, 0x42, 0x2e, 0x20, 0x20, 0x20, 0x20, 0x2f, 0x20,
-        0x40, 0x20, 0x23, 0x20,
+    0x40, 0x20, 0x23, 0x20,
     0x2f, 0x20, 0x27, 0x20, 0x77, 0x2e, 0x20, 0x20, 0x20, 0x20, 0x22, 0x2c,
-        0x0a, 0x22, 0x20, 0x20,
+    0x0a, 0x22, 0x20, 0x20,
     0x20, 0x20, 0x20, 0x20, 0x43, 0x2e, 0x44, 0x2e, 0x3b, 0x2e, 0x45, 0x2e,
-        0x46, 0x2e, 0x47, 0x2e,
+    0x46, 0x2e, 0x47, 0x2e,
     0x48, 0x2e, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x27, 0x20, 0x40, 0x20,
-        0x23, 0x20, 0x27, 0x20,
+    0x23, 0x20, 0x27, 0x20,
     0x27, 0x20, 0x40, 0x20, 0x20, 0x20, 0x22, 0x2c, 0x0a, 0x22, 0x20, 0x20,
-        0x20, 0x20, 0x20, 0x20,
+    0x20, 0x20, 0x20, 0x20,
     0x49, 0x2e, 0x4a, 0x2e, 0x32, 0x20, 0x4b, 0x2e, 0x66, 0x20, 0x4c, 0x2e,
-        0x20, 0x20, 0x20, 0x20,
+    0x20, 0x20, 0x20, 0x20,
     0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x27, 0x20, 0x3e, 0x20, 0x23, 0x20,
-        0x23, 0x20, 0x40, 0x20,
+    0x23, 0x20, 0x40, 0x20,
     0x4d, 0x2e, 0x22, 0x2c, 0x0a, 0x22, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
-        0x4e, 0x2e, 0x4f, 0x2e,
+    0x4e, 0x2e, 0x4f, 0x2e,
     0x50, 0x2e, 0x4c, 0x2e, 0x64, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
-        0x20, 0x20, 0x20, 0x20,
+    0x20, 0x20, 0x20, 0x20,
     0x20, 0x20, 0x27, 0x20, 0x27, 0x20, 0x2f, 0x20, 0x2f, 0x20, 0x20, 0x20,
-        0x20, 0x20, 0x22, 0x7d,
+    0x20, 0x20, 0x22, 0x7d,
     0x3b, 0x0a
 };
 
 void xvc_toggle_cap_type ();
 void xvc_undo_toggle_cap_type ();
 void xvc_reset_ctrl_main_window_according_to_current_prefs ();
+void xvc_get_ctrl_frame_extents (GdkWindow * window, GdkRectangle * rect);
 
-#endif     // __XVC_GNOME_UI_H__
+#endif     // _xvc_XVC_GNOME_UI_H__
