@@ -47,6 +47,7 @@
 #include <pthread.h>
 #include <limits.h>                    // PATH_MAX
 #include <X11/Intrinsic.h>
+#include <errno.h>
 
 #include "job.h"
 #include "capture.h"
@@ -61,16 +62,7 @@
 # include "xtoffmpeg.h"
 #endif     // USE_FFMPEG
 
-#ifndef DOXYGEN_SHOULD_SKIP_THIS
-extern pthread_mutex_t recording_mutex;
-extern pthread_cond_t recording_condition_unpaused;
-#endif     // DOXYGEN_SHOULD_SKIP_THIS
-
-#ifdef USE_XDAMAGE
-extern pthread_mutex_t damage_regions_mutex;
-#endif     // USE_XDAMAGE
-
-static Job *job;
+static Job *job = NULL;
 
 static void job_set_capture (void);
 
@@ -132,8 +124,6 @@ static Job *
 job_new ()
 {
 #define DEBUGFUNCTION "job_new()"
-    XVC_AppData *app = xvc_appdata_ptr ();
-
     job = (Job *) malloc (sizeof (Job));
     if (!job) {
         fprintf (stderr, "%s %s: malloc failed?!?", DEBUGFILE, DEBUGFUNCTION);
@@ -166,9 +156,13 @@ job_new ()
     job->c_info = NULL;
 
 #ifdef USE_XDAMAGE
-    job->dmg_region = XFixesCreateRegion (app->dpy, NULL, 0);
+    job->dmg_region = XCreateRegion ();
 #endif     // USE_XDAMAGE
 
+    job->capture_returned_errno = 0;
+    job->frame_moved_x = 0;
+    job->frame_moved_y = 0;
+
     return (job);
 #undef DEBUGFUNCTION
 }
@@ -180,20 +174,19 @@ void
 xvc_job_free ()
 {
 #define DEBUGFUNCTION "xvc_job_free()"
-    XVC_AppData *app = xvc_appdata_ptr ();
-
-    if (job) {
+    if (job != NULL) {
         if (job->color_table)
             free (job->color_table);
 
 #ifdef USE_XDAMAGE
-        XFixesDestroyRegion (app->dpy, job->dmg_region);
+        XDestroyRegion (job->dmg_region);
 #endif     // USE_XDAMAGE
 
         if (job->c_info)
             free (job->c_info);
 
         free (job);
+        job = NULL;
     }
 #undef DEBUGFUNCTION
 }
@@ -239,10 +232,13 @@ xvc_job_set_from_app_data (XVC_AppData * app)
     else
 #endif     // USE_FFMPEG
         cto = &(app->single_frame);
+
     // various manual settings
     // need to have the flags set to smth. before other functions try to
     // do: flags |= or smth.
     job->flags = app->flags;
+    if (app->current_mode == 0 || xvc_is_filename_mutable (cto->file))
+        job->flags &= ~(FLG_AUTO_CONTINUE);
 
     job->time_per_frame = (int) (1000 /
                                  ((float) cto->fps.num / (float) cto->fps.den));
@@ -369,7 +365,7 @@ Job *
 xvc_job_ptr (void)
 {
 #define DEBUGFUNCTION "xvc_job_ptr()"
-    if (!job)
+    if (job == NULL)
         job_new ();
     return (job);
 #undef DEBUGFUNCTION
@@ -471,6 +467,9 @@ xvc_job_dump ()
     printf ("ncolors = %i\n", job->ncolors);
     printf ("color_table = %p\n", job->color_table);
     printf ("colors = %p\n", job->colors);
+
+    printf ("capture returned error: %s\n",
+            strerror (job->capture_returned_errno));
 #undef DEBUGFUNCTION
 }
 
@@ -484,12 +483,14 @@ xvc_job_dump ()
 void
 job_state_change_signals_thread (int orig_state, int new_state)
 {
+    XVC_AppData *app = xvc_appdata_ptr ();
+
     if (((orig_state & VC_PAUSE) > 0 && (new_state & VC_PAUSE) == 0) ||
         ((orig_state & VC_STOP) == 0 && (new_state & VC_STOP) > 0) ||
         ((orig_state & VC_STEP) == 0 && (new_state & VC_STEP) > 0)
         ) {
         // signal potentially paused thread
-        pthread_cond_broadcast (&recording_condition_unpaused);
+        pthread_cond_broadcast (&(app->recording_condition_unpaused));
     }
 }
 
@@ -501,12 +502,18 @@ job_state_change_signals_thread (int orig_state, int new_state)
 void
 xvc_job_set_state (int state)
 {
+#define DEBUGFUNCTION "xvc_job_set_state()"
+    XVC_AppData *app = xvc_appdata_ptr ();
     int orig_state = job->state;
 
-    pthread_mutex_lock (&recording_mutex);
+#ifdef DEBUG
+    printf ("%s %s: setting state %i\n", DEBUGFILE, DEBUGFUNCTION, state);
+#endif     // DEBUG
+    pthread_mutex_lock (&(app->capturing_mutex));
     job->state = state;
     job_state_change_signals_thread (orig_state, job->state);
-    pthread_mutex_unlock (&recording_mutex);
+    pthread_mutex_unlock (&(app->capturing_mutex));
+#undef DEBUGFUNCTION
 }
 
 /**
@@ -517,12 +524,19 @@ xvc_job_set_state (int state)
 void
 xvc_job_merge_state (int state)
 {
+#define DEBUGFUNCTION "xvc_job_merge_state()"
+    XVC_AppData *app = xvc_appdata_ptr ();
     int orig_state = job->state;
 
-    pthread_mutex_lock (&recording_mutex);
+#ifdef DEBUG
+    printf ("%s %s: merging state %i with present %i\n", DEBUGFILE,
+            DEBUGFUNCTION, state, job->state);
+#endif     // DEBUG
+    pthread_mutex_lock (&(app->capturing_mutex));
     job->state |= state;
     job_state_change_signals_thread (orig_state, job->state);
-    pthread_mutex_unlock (&recording_mutex);
+    pthread_mutex_unlock (&(app->capturing_mutex));
+#undef DEBUGFUNCTION
 }
 
 /**
@@ -533,12 +547,18 @@ xvc_job_merge_state (int state)
 void
 xvc_job_remove_state (int state)
 {
+#define DEBUGFUNCTION "xvc_job_remove_state()"
+    XVC_AppData *app = xvc_appdata_ptr ();
     int orig_state = job->state;
 
-    pthread_mutex_lock (&recording_mutex);
+#ifdef DEBUG
+    printf ("%s %s: removing state %i\n", DEBUGFILE, DEBUGFUNCTION, state);
+#endif     // DEBUG
+    pthread_mutex_lock (&(app->capturing_mutex));
     job->state &= ~(state);
     job_state_change_signals_thread (orig_state, job->state);
-    pthread_mutex_unlock (&recording_mutex);
+    pthread_mutex_unlock (&(app->capturing_mutex));
+#undef DEBUGFUNCTION
 }
 
 /**
@@ -550,13 +570,20 @@ xvc_job_remove_state (int state)
 void
 xvc_job_merge_and_remove_state (int merge_state, int remove_state)
 {
+#define DEBUGFUNCTION "xvc_job_merge_and_remove_state()"
+    XVC_AppData *app = xvc_appdata_ptr ();
     int orig_state = job->state;
 
-    pthread_mutex_lock (&recording_mutex);
+#ifdef DEBUG
+    printf ("%s %s: merging state %i with %i removing %i\n", DEBUGFILE,
+            DEBUGFUNCTION, job->state, merge_state, remove_state);
+#endif     // DEBUG
+    pthread_mutex_lock (&(app->capturing_mutex));
     job->state |= merge_state;
     job->state &= ~(remove_state);
     job_state_change_signals_thread (orig_state, job->state);
-    pthread_mutex_unlock (&recording_mutex);
+    pthread_mutex_unlock (&(app->capturing_mutex));
+#undef DEBUGFUNCTION
 }
 
 /**
@@ -567,12 +594,19 @@ xvc_job_merge_and_remove_state (int merge_state, int remove_state)
 void
 xvc_job_keep_state (int state)
 {
+#define DEBUGFUNCTION "xvc_job_keep_state()"
+    XVC_AppData *app = xvc_appdata_ptr ();
     int orig_state = job->state;
 
-    pthread_mutex_lock (&recording_mutex);
+#ifdef DEBUG
+    printf ("%s %s: keeping %i of state %i\n", DEBUGFILE, DEBUGFUNCTION, state,
+            job->state);
+#endif     // DEBUG
+    pthread_mutex_lock (&(app->capturing_mutex));
     job->state &= state;
     job_state_change_signals_thread (orig_state, job->state);
-    pthread_mutex_unlock (&recording_mutex);
+    pthread_mutex_unlock (&(app->capturing_mutex));
+#undef DEBUGFUNCTION
 }
 
 /**
@@ -585,27 +619,37 @@ xvc_job_keep_state (int state)
 void
 xvc_job_keep_and_merge_state (int keep_state, int merge_state)
 {
+#define DEBUGFUNCTION "xvc_job_keep_and_merge_state()"
+    XVC_AppData *app = xvc_appdata_ptr ();
     int orig_state = job->state;
 
-    pthread_mutex_lock (&recording_mutex);
+#ifdef DEBUG
+    printf ("%s %s: keeping %i of state %i and merge with %i\n", DEBUGFILE,
+            DEBUGFUNCTION, keep_state, job->state, merge_state);
+#endif     // DEBUG
+    pthread_mutex_lock (&(app->capturing_mutex));
     job->state &= keep_state;
     job->state |= merge_state;
     job_state_change_signals_thread (orig_state, job->state);
-    pthread_mutex_unlock (&recording_mutex);
+    pthread_mutex_unlock (&(app->capturing_mutex));
+#undef DEBUGFUNCTION
 }
 
 #ifdef USE_XDAMAGE
-XserverRegion
+//XserverRegion
+Region
 xvc_get_damage_region ()
 {
-    XserverRegion region, dmg_region;
+    //XserverRegion region, dmg_region;
+    Region region, dmg_region;
     XVC_AppData *app = xvc_appdata_ptr ();
 
-    pthread_mutex_lock (&damage_regions_mutex);
-    region = XFixesCreateRegion (app->dpy, 0, 0);
+    pthread_mutex_lock (&(app->damage_regions_mutex));
+    //region = XFixesCreateRegion (app->dpy, 0, 0);
+    region = XCreateRegion ();
     dmg_region = job->dmg_region;
     job->dmg_region = region;
-    pthread_mutex_unlock (&damage_regions_mutex);
+    pthread_mutex_unlock (&(app->damage_regions_mutex));
     return dmg_region;
 }
 #endif     // USE_XDAMAGE
