@@ -22,8 +22,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ifndef __JOB_H__
-#define __JOB_H__
+#ifndef _xvc_JOB_H__
+#define _xvc_JOB_H__
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 #include <X11/Intrinsic.h>
@@ -32,8 +32,9 @@
 #include "colors.h"
 
 #ifdef USE_XDAMAGE
-#include <X11/extensions/Xfixes.h>
-#include <X11/extensions/Xdamage.h>
+#include <X11/Xutil.h>
+//#include <X11/extensions/Xfixes.h>
+//#include <X11/extensions/Xdamage.h>
 #endif     // USE_XDAMAGE
 
 #ifdef HAVE_CONFIG_H
@@ -64,7 +65,7 @@ enum JobStates
  * preferences, but here we need the final (potentially autodetected)
  * target.
  */
-typedef struct _Job
+typedef struct  //_job
 {
     /** \brief filename */
     char *file;
@@ -134,9 +135,15 @@ typedef struct _Job
     ColorInfo *c_info;
 
 #ifdef USE_XDAMAGE
-    XserverRegion dmg_region;
+//    XserverRegion dmg_region;
+    Region dmg_region;
 #endif     // USE_XDAMAGE
 
+    /** \brief the last capture session returned this errno */
+    int capture_returned_errno;
+
+    int frame_moved_x;
+    int frame_moved_y;
 } Job;
 
 void xvc_job_free ();
@@ -154,6 +161,7 @@ void xvc_job_keep_state (int state);
 void xvc_job_keep_and_merge_state (int merge_state, int remove_state);
 
 #ifdef USE_XDAMAGE
-XserverRegion xvc_get_damage_region ();
+//XserverRegion xvc_get_damage_region ();
+Region xvc_get_damage_region ();
 #endif     // USE_XDAMAGE
-#endif     // __JOB_H__
+#endif     // _xvc_JOB_H__
