@@ -19,8 +19,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ifndef __LED_METER_H__
-#define __LED_METER_H__
+#ifndef _xvc_LED_METER_H__
+#define _xvc_LED_METER_H__
 
 #include <gdk/gdk.h>
 #include <gtk/gtkvbox.h>
@@ -50,10 +50,10 @@ extern "C"
         LM_HIGH
     };
 
-    typedef struct _LedMeter LedMeter;
-    typedef struct _LedMeterClass LedMeterClass;
+    typedef struct _ledMeter LedMeter;
+    typedef struct _ledMeterClass LedMeterClass;
 
-    struct _LedMeter
+    struct _ledMeter
     {
         GtkVBox vbox;
         GtkWidget *ebox;
@@ -62,7 +62,7 @@ extern "C"
         gint max_da, old_max_da;
     };
 
-    struct _LedMeterClass
+    struct _ledMeterClass
     {
         GtkVBoxClass parent_class;
 
@@ -72,9 +72,9 @@ extern "C"
     GtkType led_meter_get_type (void);
     GtkWidget *led_meter_new (void);
     void led_meter_set_percent (LedMeter *, int);
-    void led_meter_set_tip (LedMeter * lm, char *tip);
+    void led_meter_set_tip (LedMeter * lm, const char *tip);
 
 #ifdef __cplusplus
 }
 #endif     /* __cplusplus */
-#endif     /* __LED_METER_H__ */
+#endif     /* _xvc_LED_METER_H__ */
