@@ -62,10 +62,6 @@ typedef void (*sighandler_t) (int);
 static XVC_AppData *app;
 static Window capture_window = None;
 
-#ifdef USE_XDAMAGE
-extern pthread_mutex_t damage_regions_mutex;
-#endif     // USE_XDAMAGE
-
 /*
  * HELPER FUNCTIONS
  */
@@ -81,7 +77,7 @@ usage (char *prog)
 
     printf
         (_
-         ("Usage: %s, ver %s, (c) rasca, berlin 1997,98,99, khb (c) 2003,04,05,06\n"),
+         ("Usage: %s, ver %s, (c) rasca, berlin 1997,98,99, khb (c) 2003-07\n"),
          prog, VERSION);
     printf (_
             ("[--fps #.#]      frames per second (float) or a fraction string like \"30000/1001\"\n"));
@@ -173,10 +169,6 @@ init (XVC_CapTypeOptions * ctos, int *argc, char *argv[])
     // because this is UI independant and would need to be here even with Qt
     XInitThreads ();
 
-#if USE_XDAMAGE
-    pthread_mutex_init (&damage_regions_mutex, NULL);
-#endif     // USE_XDAMAGE
-
     // this is a hook for a GUI to do some pre-init functions ...
     // possibly to set some fallback options read from a rc file or
     // Xdefaults
@@ -223,6 +215,8 @@ cleanup ()
 
     xvc_frame_drop_capture_display ();
 
+    if (app)
+        xvc_appdata_free (app);
 #ifdef USE_FFMPEG
     av_free_static ();
 #endif
@@ -468,7 +462,7 @@ parse_cli_options (XVC_CapTypeOptions * tmp_capture_options, int argc,
 
                     printf
                         (_
-                         ("%s, ver %s, (c) rasca, berlin 1997,98,99, khb (c) 2003,04,05,06\n"),
+                         ("%s, ver %s, (c) rasca, berlin 1997,98,99, khb (c) 2003-07\n"),
                          _argv[0], VERSION);
 
 #ifdef USE_FFMPEG
@@ -562,7 +556,7 @@ parse_cli_options (XVC_CapTypeOptions * tmp_capture_options, int argc,
 
                     printf
                         (_
-                         ("%s, ver %s, (c) rasca, berlin 1997,98,99, khb (c) 2003,04,05,06\n"),
+                         ("%s, ver %s, (c) rasca, berlin 1997,98,99, khb (c) 2003-07\n"),
                          _argv[0], VERSION);
                     printf (_("Available file formats: "));
 
@@ -623,7 +617,7 @@ parse_cli_options (XVC_CapTypeOptions * tmp_capture_options, int argc,
 
                     printf
                         (_
-                         ("%s, ver %s, (c) rasca, berlin 1997,98,99, khb (c) 2003,04,05,06\n"),
+                         ("%s, ver %s, (c) rasca, berlin 1997,98,99, khb (c) 2003-07\n"),
                          _argv[0], VERSION);
                     printf (_
                             ("Available audio codecs for multi-frame capture: "));
