@@ -58,7 +58,8 @@
 // ffmpeg stuff
 #include <ffmpeg/avcodec.h>
 #include <ffmpeg/avformat.h>
-#include <ffmpeg/dsputil.h>
+#include <ffmpeg/avdevice.h>
+//#include <ffmpeg/dsputil.h>
 #include <ffmpeg/swscale.h>
 #include <ffmpeg/rgb2rgb.h>
 #include <ffmpeg/fifo.h>
@@ -146,8 +147,10 @@ static uint8_t *scratchbuf8bit;
 static XVC_CapTypeOptions *target = NULL;
 
 #ifdef DEBUG
-static void dump8bit (XImage * image, u_int32_t * ct);
-static void dump32bit (XImage * input, ColorInfo * c_info);
+static void dump8bit (const XImage * image, const u_int32_t * ct);
+static void dump32bit (const XImage * input, const ColorInfo * c_info);
+
+/** \todo: what about const-correctness for the next line */
 static void x2ffmpeg_dump_ximage_info (XImage * img, FILE * fp);
 #endif     // DEBUG
 
@@ -217,27 +220,7 @@ typedef struct AVInputStream
                      * discontinuity */
 } AVInputStream;
 
-#ifndef DOXYGEN_SHOULD_SKIP_THIS
-/**
- * \brief external variables for thread synchronization. This is the
- *      global mutex lock for recording (changing state and such).
- *
- * This is needed for pausing audio capture when the recording thread is
- * paused.
- */
-extern pthread_mutex_t recording_mutex;
-
-/**
- * \brief external variables for thread synchronization. This is the
- *      paused condition.
- *
- * This is needed for pausing audio capture when the recording thread is
- * paused.
- */
-extern pthread_cond_t recording_condition_unpaused;
-#endif     // DOXYGEN_SHOULD_SKIP_THIS
-
-// FIXME: check if this all needs to be global
+// FIXME: check if this all needs to be static global
 /** \brief audio codec */
 static AVCodec *au_codec = NULL;
 
@@ -271,6 +254,8 @@ static pthread_mutex_t mp = PTHREAD_MUTEX_INITIALIZER;
  *      capture. This is the thread's id */
 static pthread_t tid = 0;
 
+static int audio_thread_running = FALSE;
+
 /** \brief store current audio_pts for a/v sync */
 static double audio_pts;
 
@@ -307,13 +292,13 @@ add_audio_stream (Job * job)
 
     // prepare input stream
     memset (ap, 0, sizeof (*ap));
-    ap->device = job->snd_device;
+//    ap->device = job->snd_device;
 
     if (grab_audio) {
         ap->sample_rate = target->sndrate;
         ap->channels = target->sndchannels;
 
-        grab_iformat = av_find_input_format ("audio_device");
+        grab_iformat = av_find_input_format ("oss");
 #ifdef DEBUG
         printf ("%s %s: grab iformat %p\n", DEBUGFILE, DEBUGFUNCTION,
                 grab_iformat);
@@ -324,8 +309,8 @@ add_audio_stream (Job * job)
     }
 
     err =
-        av_open_input_file (&ic, ap->device, (grab_audio ? grab_iformat : NULL),
-                            0, ap);
+        av_open_input_file (&ic, job->snd_device,
+                            (grab_audio ? grab_iformat : NULL), 0, ap);
     if (err < 0) {
         fprintf (stderr, _("%s %s: error opening input file %s: %i\n"),
                  DEBUGFILE, DEBUGFUNCTION, job->snd_device, err);
@@ -531,7 +516,7 @@ add_audio_stream (Job * job)
  */
 static void
 do_audio_out (AVFormatContext * s, AVOutputStream * ost,
-              AVInputStream * ist, unsigned char *buf, int size)
+              const AVInputStream * ist, unsigned char *buf, int size)
 {
 #define DEBUGFUNCTION "do_audio_out()"
     uint8_t *buftmp;
@@ -725,6 +710,7 @@ cleanup_thread_when_stopped ()
     printf ("%s %s: Leaving\n", DEBUGFILE, DEBUGFUNCTION);
 #endif     // DEBUG
 
+    audio_thread_running = FALSE;
     pthread_exit (&ret);
 #undef DEBUGFUNCTION
 }
@@ -739,6 +725,7 @@ static void
 capture_audio_thread (Job * job)
 {
 #define DEBUGFUNCTION "capture_audio_thread()"
+    XVC_AppData *app = xvc_appdata_ptr ();
     unsigned long start, stop, start_s, stop_s;
     struct timeval thr_curr_time;
     long sleep;
@@ -748,6 +735,7 @@ capture_audio_thread (Job * job)
     static short *samples = NULL;
     AVPacket pkt;
 
+    audio_thread_running = TRUE;
     signal (SIGUSR1, cleanup_thread_when_stopped);
 
     while (TRUE) {
@@ -757,9 +745,10 @@ capture_audio_thread (Job * job)
         start = thr_curr_time.tv_usec;
 
         if ((job->state & VC_PAUSE) && !(job->state & VC_STEP)) {
-            pthread_mutex_lock (&recording_mutex);
-            pthread_cond_wait (&recording_condition_unpaused, &recording_mutex);
-            pthread_mutex_unlock (&recording_mutex);
+            pthread_mutex_lock (&(app->recording_paused_mutex));
+            pthread_cond_wait (&(app->recording_condition_unpaused),
+                               &(app->recording_paused_mutex));
+            pthread_mutex_unlock (&(app->recording_paused_mutex));
         } else if (job->state == VC_REC) {
 
             audio_pts = (double)
@@ -876,6 +865,7 @@ capture_audio_thread (Job * job)
         usleep (sleep);
     }                                  // end while(TRUE) loop
     ret = 1;
+    audio_thread_running = FALSE;
     pthread_exit (&ret);
 #undef DEBUGFUNCTION
 }
@@ -1145,7 +1135,7 @@ prepareOutputFile (char *jFileName, AVFormatContext * oc, int number)
  * @return pointer to the AVStream that has been added to the output format
  */
 static AVStream *
-add_video_stream (AVFormatContext * oc, XImage * image,
+add_video_stream (AVFormatContext * oc, const XImage * image,
                   int input_pixfmt, int codec_id, Job * job)
 {
 #define DEBUGFUNCTION "add_video_stream()"
@@ -1169,11 +1159,6 @@ add_video_stream (AVFormatContext * oc, XImage * image,
     st->codec->codec_id = codec_id;
     st->codec->codec_type = CODEC_TYPE_VIDEO;
 
-    // mt init
-    if (codec_id == CODEC_ID_MPEG4 || codec_id == CODEC_ID_MPEG1VIDEO ||
-        codec_id == CODEC_ID_MPEG2VIDEO) {
-        avcodec_thread_init (st->codec, 4);
-    }
     // find the video encoder
     codec = avcodec_find_encoder (st->codec->codec_id);
     if (!codec) {
@@ -1188,14 +1173,14 @@ add_video_stream (AVFormatContext * oc, XImage * image,
         int n;
         double r;
 
-        r = sqrt (100 / app->rescale);
+        r = sqrt ((double) app->rescale / 100.0);
 
-        n = image->width / r;
+        n = image->width * r;
         if (n % 2 > 0)
             n--;
         st->codec->width = n;
 
-        n = image->height / r;
+        n = image->height * r;
         if (n % 2 > 0)
             n--;
         st->codec->height = n;
@@ -1203,6 +1188,15 @@ add_video_stream (AVFormatContext * oc, XImage * image,
         st->codec->width = image->width;
         st->codec->height = image->height;
     }
+
+    // mt init
+    if (codec_id == CODEC_ID_MPEG4 || codec_id == CODEC_ID_MPEG1VIDEO ||
+        codec_id == CODEC_ID_MPEG2VIDEO) {
+        // the max threads is taken from ffmpeg's mpegvideo.c
+        avcodec_thread_init (st->codec, XVC_MIN (4,
+                                                 (st->codec->height +
+                                                  15) / 16));
+    }
     // time base: this is the fundamental unit of time (in seconds) in
     // terms of which frame timestamps are represented. for fixed-fps
     // content, timebase should be 1/framerate and timestamp increments
@@ -1286,7 +1280,7 @@ add_video_stream (AVFormatContext * oc, XImage * image,
  * @return libavcodec's picture format
  */
 static int
-guess_input_pix_fmt (XImage * image, ColorInfo * c_info)
+guess_input_pix_fmt (const XImage * image, const ColorInfo * c_info)
 {
 #define DEBUGFUNCTION "guess_input_pix_fmt()"
     int input_pixfmt;
@@ -1388,7 +1382,7 @@ xvc_ffmpeg_save_frame (FILE * fp, XImage * image)
     XVC_AppData *app = xvc_appdata_ptr ();
 
     /* size of the encoded frame to write to file */
-    int out_size;
+    int out_size = -1;
 
 #ifdef DEBUG
     printf ("%s %s: Entering\n", DEBUGFILE, DEBUGFUNCTION);
@@ -1439,6 +1433,7 @@ xvc_ffmpeg_save_frame (FILE * fp, XImage * image)
         input_pixfmt = guess_input_pix_fmt (image, job->c_info);
 
         // register all libav* related stuff
+        avdevice_register_all ();
         av_register_all ();
 
         // guess AVOutputFormat
@@ -1600,10 +1595,10 @@ xvc_ffmpeg_save_frame (FILE * fp, XImage * image)
         /*
          * prepare output buffer for encoded frames
          */
-        if ((image_size + 200) < FF_MIN_BUFFER_SIZE)
+        if ((image_size + 20000) < FF_MIN_BUFFER_SIZE)
             outbuf_size = FF_MIN_BUFFER_SIZE;
         else
-            outbuf_size = image_size + 200;
+            outbuf_size = image_size + 20000;
         outbuf = malloc (outbuf_size);
         if (!outbuf) {
             fprintf (stderr,
@@ -1770,7 +1765,7 @@ xvc_ffmpeg_save_frame (FILE * fp, XImage * image)
     }
 
     if (job->target < CAP_MF)
-        url_fclose (&output_file->pb);
+        url_fclose (output_file->pb);
 
 #ifdef HAVE_FFMPEG_AUDIO
     /*
@@ -1806,6 +1801,13 @@ xvc_ffmpeg_clean ()
         {
             int tret;
 
+            // wait till audio thread is actually running, or else
+            // the signal might kill xvidcap. we also cannot just
+            // drop sending the signal, because the audio thread
+            // might just be starting
+            while (!audio_thread_running) {
+                usleep (10);
+            }
             tret = pthread_kill (tid, SIGUSR1);
 
             pthread_join (tid, NULL);
@@ -1828,7 +1830,7 @@ xvc_ffmpeg_clean ()
          * close file if multi-frame capture ... otherwise closed already
          */
         if (job->target >= CAP_MF)
-            url_fclose (&output_file->pb);
+            url_fclose (output_file->pb);
         /*
          * free streams
          */
@@ -1941,7 +1943,7 @@ x2ffmpeg_dump_ximage_info (XImage * img, FILE * fp)
  * @param input XImage to dump to pnm
  */
 static void
-dump32bit (XImage * input, ColorInfo * c_info)
+dump32bit (const XImage * input, const ColorInfo * c_info)
 {
 #define DEBUGFUNCTION "dump32bit()"
 
@@ -2008,7 +2010,7 @@ dump32bit (XImage * input, ColorInfo * c_info)
  * @param ct pointer to color table
  */
 static void
-dump8bit (XImage * image, u_int32_t * ct)
+dump8bit (const XImage * image, const u_int32_t * ct)
 {
 #define DEBUGFUNCTION "dump8bit()"
 
