@@ -1,7 +1,8 @@
+/**
+ * \file xtoffmpeg.h
+ */
 /*
- * xtoffmpeg.h
- *
- * Copyright (C) 2003 Karl H. Beckers, Frankfurt
+ * Copyright (C) 2003-07 Karl H. Beckers, Frankfurt
  * EMail: khb@jarre-de-the.net
  *
  * This program is free software; you can redistribute it and/or modify
@@ -11,7 +12,7 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
@@ -19,6 +20,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-void XImageToFFMPEG (FILE *fp, XImage *image, Job *job);
-void *FFMPEGcolorTable (XColor *colors, int ncolors); 
-void FFMPEGClean (Job *job);
+#ifndef _xvc_X_TO_FFMPEG_H__
+#define _xvc_X_TO_FFMPEG_H__
+
+void xvc_ffmpeg_save_frame (FILE * fp, XImage * image);
+void *xvc_ffmpeg_get_color_table (XColor * colors, int ncolors);
+void xvc_ffmpeg_clean ();
+
+#endif     // _xvc_X_TO_FFMPEG_H__
